;world: netlogo world
;map: geophysical map

;NLU-: Net Logo Unit
;RU-: Real Unit


;;;; EXTENSIONS ;;;;
extensions [gis profiler array]

;;;; GLOBALS ;;;;

;;define global variables
globals[
  ;space
  MIN-LON
  MAX-LON
  MIN-LAT
  MAX-LAT

  ;time
  ;number of days per tick
  TIME-STEP ; in days

  ;sites
  N-NESTING-SITES
  N-FORAGING-PATCHES
  ;colors for nesting sites
  SITES-COLORS

  ;a matrix with the distance betwwen the sites
  DISTANCES-BETWEEN-SITES-MATRIX
  ;record maximum distance between 2 feeding patches
  MAXIMUM-DISTANCES-BETWEEN-FEEDING-PATCHES
  ;If we want to export this matrix distance to a file
  EXPORT-FEEDING-PATCHES-DISTANCES-MATRIX


  ;gturtles
  GTURTLE-DEFAULT-SIZE
  AVERAGE-SWIMMING-SPEED

  GLOBAL-RU-MAXIMUM-VISIBILITY
  migration-speed

  ;distance within it is considered that turtle has reached the site
  REACHING-SITE-DISTANCE-TOLERANCE

  ;minimal distance between foraging and nesting sites
  RU-MINIMAL-DISTANCE-BETWEEN-FEEDING-NESTING-SITE


  ;actual or present date :
  ;Caution this is in date (eg days) unit not in tick
  TODAY-DATE

  ;matrix to study foraging sites usage
  ;(number of foraging sites xnumber of nesting sites)
  ;time spent on this site
  foraging-nesting-time-usage
  ;number of times visited
  foraging-nesting-turtle-visits
  ;number of times that it has been chosen by a new turtle
  foraging-nesting-turtle-chosen


  ;simulation start and end time
  simulation-start-date
  simulation-end-date

  ;recording or not (initialisation)
  MINIMUM-STEP-BEFORE-RECORDING

  ;record can start if
     ;1/record is true
     ;2/the number of step is greater than minimum step before recording
  record-validated

  ;recovery (growth) of the feeding patches
  patch-regrowth-rate

  ;should i draw from gis
  gis
]

;;set global variables
to setup-globals
  ;map boundaries in decimal degrees
  set MIN-LON 25
  set MAX-LON 63.65
  set MIN-LAT -29
  set MAX-LAT 10

  ;time step (in days)
  ;1 tick is equal to 'TIME-STEP' days
  set TIME-STEP 0.5


  file-open (word "../data/" the-map "_nestingsites.txt")
  let nlines 0
  let flush ""
  while [not file-at-end?]
  [
    set flush file-read-line
    set nlines nlines + 1
  ]
  file-close


  set N-NESTING-SITES nlines

  file-open (word "../data/" the-map "_feedingpatches.txt")
  set nlines 0
  set flush ""
  while [not file-at-end?]
  [
    set flush file-read-line
    set nlines nlines + 1
  ]
  file-close

  set N-FORAGING-PATCHES nlines



  ;define colors for the first 4 nesting sites
  set SITES-COLORS (list red magenta brown sky green pink orange lime turquoise violet cyan 38 78 138)

  ;pcolor of ground patches
  ;set PCOLOR-OF-GROUND 35
  ;NOTE: in case of gis map, the color used will be the one of the gis

  ;distance within it is considered that turtle has reached the site
  set REACHING-SITE-DISTANCE-TOLERANCE 4


  ;minimal distance between foraging and nesting sites (in kms)
  set RU-MINIMAL-DISTANCE-BETWEEN-FEEDING-NESTING-SITE 200

  ;export the distance matrix for further investigation outside netlogo
  set EXPORT-FEEDING-PATCHES-DISTANCES-MATRIX TRUE
  set MAXIMUM-DISTANCES-BETWEEN-FEEDING-PATCHES []



  ;default size of turtles (pixels)
  set GTURTLE-DEFAULT-SIZE 5

  ;maximum visibility of sea turtle (km)
  set GLOBAL-RU-MAXIMUM-VISIBILITY 100
  ;swimming/travel speed of sea turtles (km/h)
  set migration-speed 2.7

  ;foraging sites usage matrices
  ;time usage matrice
  set foraging-nesting-time-usage array:from-list n-values N-NESTING-SITES [array:from-list n-values N-FORAGING-PATCHES [0]]
  ;turtle number of visits usage matrice
  set foraging-nesting-turtle-visits array:from-list n-values N-NESTING-SITES [array:from-list n-values N-FORAGING-PATCHES [0]]
  ;number of times that a turtle has choosen this site
  set foraging-nesting-turtle-chosen array:from-list n-values N-NESTING-SITES [array:from-list n-values N-FORAGING-PATCHES [0]]


  set simulation-start-date format-date date-and-time
  ;the end date is updated at each time step
  set simulation-end-date format-date date-and-time

  ;threshold for recording
  set MINIMUM-STEP-BEFORE-RECORDING 3000

  ;record can start ?
  set record-validated false

  ;recovery (growth) of the feeding patches
  set patch-regrowth-rate intake-proportion * N-GTURTLES / N-FORAGING-PATCHES * maximum-feeding-patch-resource-level / (maximum-feeding-patch-resource-level - maximum-feeding-patch-resource-level / 2)

  ;gis deprecated
  set gis FALSE

end


;;;; AGENT DEFINITION ;;;;

;;define agent types
breed[gturtles gturtle]
breed[nesting-sites nesting-site]
breed[feeding-patches feeding-patch]


;;define gturtles variables
gturtles-own[
  ;;;; STATE VARIABLES ;;;;
  ; These values can be different among individuals and cannot be deduced from other variables

  ;; Location
  ;xcor (by default in netlogo)
  ;ycor (by default in netlogo)

  ;; Current feeding patch
  gt-feeding-patch

  ;; Nesting site
  gt-nesting-site

  ;;Internal state
  ;either : prenesting - nesting - postnesting - foraging
  gt-internal-state

  ;; Internal energy level at time step t
  energy-level

  ;; Foraging fidelity strategy
  foraging-fidelity-strategy

  ;; Nesting allocation strategy
  nesting-allocation-strategy

  ;MIGRATION
  ;which side to avoid obstacle
  ;0 : not defined
  ;1 : to the right
  ;-1 : to the left
  gt-avoidance-side


  ;;;; AUXILIARY VARIABLES ;;;;
  ;;; 1/ These variables are fixed and shared by all inviduals

  ;; MIGRATION
  ; Migration speed
  NLU-speed ; (calculated from migration-speed)

  ;;Maximum visibility in netlogo distance
  NLU-maximum-visibility

  ;;; 2/ These variables can be computed from other variables

  ;subvariables of strategies
  ;prenesting threshold
  prenesting-threshold

  ;energy allocated to nesting
  energy-allocated-to-nesting

  ;;; 3/ These variables are only used for calculation or observations

  ;;MIGRATION
  ;Distance of last prenesting migration
  last-prenesting-migration-distance
  ;Distance of last postnesting migration
  last-postnesting-migration-distance
  ;Distance of last foraging search migration
  last-foraging-migration-distance

  ;Current migration distance travelled
  current-migration-distance

  ;Date and duration of migrations
  ;prenesting
  last-prenesting-starting-date
  last-prenesting-duration

  ;postnesting
  last-postnesting-starting-date
  last-postnesting-duration

  ;foraging
  last-foraging-migration-starting-date
  last-foraging-migration-duration

  ;;NESTING

  ;is it the first nest of my season
  nesting-started?
  energy-level-when-nesting-starts
  energy-level-when-nesting-stops

  ;list of nesting dates
  nesting-season-starting-dates
  ;duration of last internesting period
  last-remigration-interval

]


;Define patches variables
patches-own[
  ;  nothing since sea currents are coded in existing patch rgb color variables
]

;Define what sites own
nesting-sites-own[

  ;;;; SECONDARY STATE VARIABLES ;;;;
  ;; These variable are only used for values computation or observation

  ; Id number
  nesting-site-id

  ;List of date where a nesting event occured
  list-date-of-nesting-occurence
  ;List of energy level of turtles after nesting occured
  list-energy-level-when-nesting-stops
  ;Number of actual nesting turtles
  number-of-local-nesting-gturtles

  ;Distance to other feeding patches (and nesting sites)
  distances-to-sites-and-patches
  ;Use to assign first patch to a turtle
  descreasing-exponential-probability-for-other-feeding-patches

  ;Number of turtle to assign to this site at initialisation
  maximum-number-of-local-nesting-gturtles
]

feeding-patches-own[
  ;;;; MAIN STATE VARIABLES ;;;;

  ;Location
  ;xcor (by default in netlogo)
  ;ycor (by default in netlogo)

  ;Feeding patch resource level
  feeding-patch-resource-level

  ;Number of turtles on feeding patch p at time t
  feeding-patch-nturtles

  ;;;; SECONDARY STATE VARIABLES ;;;;
  ;; These variable are only used for values computation or observation

  ;Id number
  feeding-patch-id

  ;Distance to other feeding patches
  distances-to-sites-and-patches

  ;Use to assign a new patch to a turtle foraging in this patch
  descreasing-exponential-probability-for-other-feeding-patches
]


;;;; MODEL SETUP ;;;;
to setup
  output-print date-and-time

  setup-map
  setup-turtles-and-sites
  print "1 sim started"

  if movie [
    movie-start (word "movie/" simulation-start-date "_" behaviorspace-run-number "_movie.mov")
    movie-set-frame-rate 25
  ]

end

; setup the model
to setup-turtles-and-sites
  clear-turtles

  ;Check of parameters
  ;if in one single tick turtles moves further
  ;that the distance it can effectively see
  ;then the ibm won't run
  if (tick2time (migration-speed * 24) > GLOBAL-RU-MAXIMUM-VISIBILITY)
  [
    print "Warning : Turtles move calculation exceeds maximum visibility"
    print "Solution : lower TIME-STEP"
  ]

  if (migration-speed > GLOBAL-RU-MAXIMUM-VISIBILITY)
  [
    print "Warning : Turtles moving capacity exceeds maximum visibility"
    print "Solution : lower migration-speed"
  ]


  ;setup sites
  setup-nesting-sites
  setup-feeding-patches

  ;evaluate between sites distance matrix
  if (EXPORT-FEEDING-PATCHES-DISTANCES-MATRIX)
  [
    export-distances-between-sites-matrix
  ]
  ;calculate distance for each site
  foreach sort feeding-patches [
    ask ? [
      setup-distances-to-sites-and-patches
    ]]

  foreach sort nesting-sites [
    ask ? [
      setup-distances-to-sites-and-patches
    ]]

  setup-MAXIMUM-DISTANCES-BETWEEN-FEEDING-PATCHES

  foreach sort feeding-patches [
    ask ? [
      setup-descreasing-exponential-probability-for-other-feeding-patches
    ]]

  foreach sort nesting-sites [
    ask ? [
      setup-descreasing-exponential-probability-for-other-feeding-patches
    ]]


  ;setup green turtles
  setup-gturtles


  foreach sort nesting-sites[
  ask ? [
    output-type nesting-site-id
    output-show number-of-local-nesting-gturtles
  ]]




  if (record-migration or record-nesting)
  [

    carefully [file-delete "../results/migration_details.txt"][]

    file-open (word "../results/" simulation-start-date "_" behaviorspace-run-number "_events_details.txt")

    write-events-file-headers


    if record-nesting [
      foreach sort gturtles [
        ask ?[

          write-events-file-setup
        ]
      ]
    ]
  ]


end


;;;; GIS MAP SETUP ;;;;
to setup-map
  file-close-all

  ;clear all
  ;; (for this model to work with NetLogo's new plotting features,
  ;; __clear-all-and-reset-ticks should be replaced with clear-all at
  ;; the beginning of your setup procedure and reset-ticks at the end
  ;; of the procedure.)
  __clear-all-and-reset-ticks

  ;set global variables
  setup-globals

  ;if gis button is on
  ifelse gis
  [
    let sooi-land-map gis:load-dataset "../data/SOOI.shp"

    ;boundaries setting
    gis:set-world-envelope (gis:envelope-union-of (gis:envelope-of sooi-land-map))

    ;transformation settings
    gis:set-transformation (list MIN-LON MAX-LON MIN-LAT MAX-LAT) (list min-pxcor max-pxcor min-pycor max-pycor)

    ;set the color from the gis table to the pcolor of the corresponding patches
    gis:apply-coverage sooi-land-map "PCOLOR" pcolor
  ]
  ;if gis button is off .gif image is used
  [
    ;import-pcolors (word "maps/" the-map ".gif")
    import-pcolors-rgb (word "../data/" the-map ".png")
    ask patches [
      if pcolor = 0 [set pcolor [0 0 0]] ; pcolor to 1 is arbitrary
    ]

  ]


  ;pixel size in km
  pixel-size-in-map-distance
end



;;;; SITES SETUP ;;;;

;initialize nesting-sites
to setup-nesting-sites
  file-open (word "../data/" the-map "_nestingsites.txt")
  create-nesting-sites N-NESTING-SITES [
    set size 15
    let lon lon2xcor file-read
    let lat lat2ycor file-read
    set maximum-number-of-local-nesting-gturtles file-read
    set nesting-site-id file-read

    setxy lon lat

    set shape "circle"
    set list-date-of-nesting-occurence []
    set list-energy-level-when-nesting-stops []

    ;For now no turtles are allocated to the nesting sites
    set number-of-local-nesting-gturtles 0

    ifelse SITES-COLORS != []
    [
      set color first SITES-COLORS
      set SITES-COLORS but-first SITES-COLORS
    ]
    [
      set color turquoise
    ]


    ;distances and probabilities to foraging sites
    set distances-to-sites-and-patches []
    set descreasing-exponential-probability-for-other-feeding-patches []
  ]

  file-close
end


;intialize feeding-patches
to setup-feeding-patches
  file-open (word "../data/" the-map "_feedingpatches.txt")
  create-feeding-patches N-FORAGING-PATCHES [
    set size 8
    let lon lon2xcor file-read
    let lat lat2ycor file-read
    set feeding-patch-id file-read

    setxy lon lat
    set shape "square"

    ;init the initial stock-level for a site
    ifelse(site-depletion)
    [
      set feeding-patch-resource-level (random maximum-feeding-patch-resource-level)
      color-feeding-patch
    ]
    [
      set feeding-patch-resource-level maximum-feeding-patch-resource-level
      set color green
    ]

    ;We must check that the site is not located on ground
    ;otherwise can be set up fins at initialisation
    let i 0
    while [(i < 100) and is-ground? patch-here]
    [
      set i (i + 1)
      setxy (lon + i) lat
    ]

    if i = 100 [print "WARNING : A feeding site has been set up on ground"]

    ;distances and probabilities are not known at the moment
    set distances-to-sites-and-patches []
    set descreasing-exponential-probability-for-other-feeding-patches []


    ;for now there are no turtles around
    set feeding-patch-nturtles 0

  ]
  file-close
end




to export-distances-between-sites-matrix
  let distances-list [-1]

  carefully [file-delete "distmatrix.txt"][]
  file-open "distmatrix.txt"

  foreach sort feeding-patches [
    ask ? [
      foreach sort feeding-patches [
        ask ?
        [
          file-type precision NLU2RU-dist(distance myself) 4
          file-type " "
        ]]
      file-print ""]]

  file-close

end

to setup-distances-to-sites-and-patches
  let the-distances []

  foreach sort feeding-patches [
        ask ?
        [
          set the-distances lput precision NLU2RU-dist(distance myself) 2 the-distances
        ]]

  set distances-to-sites-and-patches the-distances
end


;transform distances vector to probability vectors according to an "exponent" decreasing function
to setup-descreasing-exponential-probability-for-other-feeding-patches2
  foreach distances-to-sites-and-patches [
    set descreasing-exponential-probability-for-other-feeding-patches fput ((1 - ? / MAXIMUM-DISTANCES-BETWEEN-FEEDING-PATCHES) ^ feeding-patch-allocation-exponent * 1000) descreasing-exponential-probability-for-other-feeding-patches]
end

to setup-descreasing-exponential-probability-for-other-feeding-patches
  let the-probabilities []

  let corrected-distances []
  if (min distances-to-sites-and-patches = 0) [
    foreach distances-to-sites-and-patches [
       set corrected-distances lput (? - first butfirst sort distances-to-sites-and-patches) corrected-distances
      ]
    ]

  let the-max max distances-to-sites-and-patches
  let the-min min distances-to-sites-and-patches
  if(the-min = 0)[set the-min first butfirst sort distances-to-sites-and-patches]

  foreach distances-to-sites-and-patches [
    set the-probabilities lput ((1 - (? - the-min) / (the-max - the-min)) ^ feeding-patch-allocation-exponent * 1000) the-probabilities]


  set descreasing-exponential-probability-for-other-feeding-patches the-probabilities
end




to setup-MAXIMUM-DISTANCES-BETWEEN-FEEDING-PATCHES
  ask feeding-patches [
    set MAXIMUM-DISTANCES-BETWEEN-FEEDING-PATCHES max fput MAXIMUM-DISTANCES-BETWEEN-FEEDING-PATCHES distances-to-sites-and-patches]
  ask nesting-sites [
    set MAXIMUM-DISTANCES-BETWEEN-FEEDING-PATCHES max fput MAXIMUM-DISTANCES-BETWEEN-FEEDING-PATCHES distances-to-sites-and-patches]
end



;;;; GTURTLES SETUP ;;;;

;initialize turtles
to setup-gturtles
  create-gturtles N-GTURTLES [
    ;;Geometry:
    set shape "turtle"
    set size GTURTLE-DEFAULT-SIZE
    set NLU-maximum-visibility RU2NLU-dist GLOBAL-RU-MAXIMUM-VISIBILITY


    ;;Sites:
    ;set nesting and foraging site
    ;see associated function
    allocates-nesting-site nesting-attribution-method
    allocates-feeding-patch initial-feeding-patch-allocation


    ;turtle take the color of the nesting site
    set color [color] of gt-nesting-site

    ;initialization of internal state
    setup-internal-state

    ;;Position and Orientation:
    ;initial position
    ;see associated function
    allocates-initial-position

    ;orientation towards target-site
    set heading target-site-heading

    ;;Migration:
    ;side to avoid coast (no initial preference (=0))
    set gt-avoidance-side 0

    set last-prenesting-starting-date ""
    set last-prenesting-duration ""

    set last-postnesting-starting-date ""
    set last-postnesting-duration ""

    set last-foraging-migration-starting-date ""
    set last-foraging-migration-duration ""


    ;last migration distance is undefined
    set last-prenesting-migration-distance ""
    set last-postnesting-migration-distance ""

    set current-migration-distance 0

    ;NLU speed en pixel/tick (RU speed en km/h)
    ;* 24 to put RU speed in km/j
    ;RU2NLU-dist to put it in pixels/jour
    ;
    set NLU-speed RU2NLU-dist (migration-speed * 24) * tick2time 1

    ;;Nesting:
    ;creating an empty entry in the list of nesting dates and period
    ;basically no parameters are defined initially
    set nesting-started? false
    set energy-level-when-nesting-starts 0
    set energy-level-when-nesting-stops 0
    set nesting-season-starting-dates []
    set last-remigration-interval ""


    ;fidelity trend to foraging site
    ;random
    ;fixed
    ifelse (feeding-patch-fidelity-strategy = "fixed")
    [
      set foraging-fidelity-strategy fidelity-strategy-indice
    ]
    [
      set foraging-fidelity-strategy random-float 1
    ]

    ifelse (nesting-strategy = "fixed")
    [
      set nesting-allocation-strategy nesting-strategy-indice
    ]
    [
      ;nesting
      set nesting-allocation-strategy random-float 1
    ]

    ;;Energy:
    ;setting subvariables
    ;energy allocated is something smaller than the maximum energy allocation
    set energy-allocated-to-nesting evaluate-total-nesting-energy-expenditure

    ;energy threshold to start prenesting (depending on the energy evaluated to the whole cycle)
    set prenesting-threshold evaluate-energy-cycle

    setup-energy-level



    ;FOR TESTING
    ;if there is only one turtle,
    ;its sites are colored in yellow
    ; for visual purpose
    if N-GTURTLES = 1
    [
      ask gt-nesting-site [set color yellow]
      ask gt-feeding-patch [set color yellow]
      ;inspect gturtle (nb-nesting-sites + nb-feeding-patches)
    ]

  ]
end

to setup-internal-state

  set-internal-state-foraging

end


to setup-energy-level

  if (prenesting-start-method = "threshold")
  [
  set energy-level random-float minimal-energy-for-prenesting
  ;set energy-level 25
  ]
  if (prenesting-start-method = "distance-dependant")
  [
    ifelse (gt-internal-state = "nesting")
    [
      set energy-level random-float minimal-energy-for-prenesting
    ]
    [
      let cycle-energy-expenditure evaluate-energy-cycle ;+ prenesting-leaving-strategy * evaluate-energy-cycle
      set energy-level random-float cycle-energy-expenditure
    ]
  ]

  if (gt-internal-state = "nesting") [
  set energy-level-when-nesting-starts energy-level]

end


;nesting-site allocation
to allocates-nesting-site [method]
  if method = "equal-number"
    [
      set gt-nesting-site first sort-by [[number-of-local-nesting-gturtles] of ?1 < [number-of-local-nesting-gturtles] of ?2] nesting-sites
      ask gt-nesting-site [set number-of-local-nesting-gturtles number-of-local-nesting-gturtles + 1]
    ]

  if method = "fixed"
    [

      ;maximum-number-of-turtle is relative to the toal number of turtles in the file !
      let ratio N-GTURTLES / sum [maximum-number-of-local-nesting-gturtles] of nesting-sites

      let the-nesting-site one-of nesting-sites

      while [([number-of-local-nesting-gturtles] of the-nesting-site) >= ([maximum-number-of-local-nesting-gturtles] of the-nesting-site * ratio)]
      [
        set the-nesting-site one-of nesting-sites
      ]

      set gt-nesting-site the-nesting-site
      ask gt-nesting-site [set number-of-local-nesting-gturtles number-of-local-nesting-gturtles + 1]
    ]

  ;first implemented method : random
  if method = "random"
    [
      set gt-nesting-site one-of nesting-sites
      ask gt-nesting-site [set number-of-local-nesting-gturtles number-of-local-nesting-gturtles + 1]
    ]
end


;foraging site allocation
to allocates-feeding-patch [method]
  ;first implemented method : random

  ifelse method = "random"
  [
    set gt-feeding-patch feeding-patch (N-NESTING-SITES + random N-FORAGING-PATCHES)

    ;Important if the foraging site is to close from the nesting site
    ;the foraging site has to be resampled
    ;because we do not observe sendendary individuals
    let NLU-minimal-distance RU2NLU-dist RU-MINIMAL-DISTANCE-BETWEEN-FEEDING-NESTING-SITE
    let the-nesting-site gt-nesting-site
    while [([distancexy [xcor] of the-nesting-site [ycor] of the-nesting-site] of gt-feeding-patch) < NLU-minimal-distance]
    [set gt-feeding-patch feeding-patch (N-NESTING-SITES + random N-FORAGING-PATCHES)]
  ]
  [
    ;initial site is distant dependant
    ifelse method = "decreasing-exponential"
    [
      allocate-new-feeding-patch gt-nesting-site method
    ]
    [
      ifelse method = "closest"
      [
      ]
      [
        set gt-feeding-patch feeding-patch (N-NESTING-SITES + N-FORAGING-PATCHES)
      ]
    ]
  ]


end




;initial position allocation
;is selected
to allocates-initial-position
  let xinit 0
  let yinit 0

  ifelse gt-internal-state = "feeding"
  [
    set xinit [xcor] of gt-feeding-patch
    set yinit [ycor] of gt-feeding-patch
  ]
  [
    ifelse gt-internal-state = "nesting"
    [
      set xinit [xcor] of gt-nesting-site
      set yinit [ycor] of gt-nesting-site
    ]

    ;else
    ;a random position in between the foraging and the foraging site
    [
      let x1 [xcor] of gt-feeding-patch
      let y1 [ycor] of gt-feeding-patch
      let x2 [xcor] of gt-nesting-site
      let y2 [ycor] of gt-nesting-site


      ;x coordinates is selected randomly
      set xinit x1 + random-float (x2 - x1)
      set yinit []
      ifelse (x2 - x1) != 0
      [set yinit y1 + (abs(xinit - x1) / abs(x2 - x1) * (y2 - y1)) ]
      [set yinit y1 + random-float (y2 - y1)]

      ;y coordinates is selected depending on x
      ;to ensure that the turtle is in a path in between
      ;the two sites (foraging and nesting)
      while [(is-ground? (patch-at xinit yinit)) = true]
      [
        set xinit x1 + random-float (x2 - x1)
        set yinit []
        ifelse (x2 - x1) != 0
        [set yinit y1 + (abs(xinit - x1) / abs(x2 - x1) * (y2 - y1)) ]
        [set yinit y1 + random-float (y2 - y1)]
      ]
    ]

  ]

  setxy xinit yinit

  ;We must check that the site is not located on ground
  ;otherwise can be set up on ground at initialisation
  let i 0
  while [i < 1000 and is-ground? patch-here]
  [
    setxy (xinit + random 5) (yinit + random 5)
    set i (i + 1)
  ]

  if i = 1000 [print "WARNING : A turtle has been set up on ground"]


end




;;;; PROGRAM RUN ;;;;
to go
  if movie [movie-grab-view]

  set TODAY-DATE tick2time ticks

  ask gturtles [
    if (is-ground? patch-here) [print "WARNING : A turtle is on ground"]

    ifelse gt-internal-state = "feeding" [feeds]
    [ifelse gt-internal-state = "prenesting" [prenesting-migrates]
      [ifelse gt-internal-state = "postnesting" [postnesting-migrates]
        [ifelse gt-internal-state = "nesting" [nests]
          [ifelse gt-internal-state = "foraging-migration" [between-feeding-patches-migrates][print "Could not evaluate gturtle internal state"]]]]]

    if (is-ground? patch-here) [show "turtle on ground"]

    ;To keep tracks of turtles
    if keep-tracks [pen-down]
  ]


  if(display-plots)[
    ;shrinking lists for memory reasons:
    ask nesting-sites [
      (foreach list-date-of-nesting-occurence list-energy-level-when-nesting-stops
        [
          if ((TODAY-DATE - ?1) > 60)
          [
            set list-energy-level-when-nesting-stops remove-item (position ?2 list-energy-level-when-nesting-stops) list-energy-level-when-nesting-stops
            set list-date-of-nesting-occurence remove-item (position ?1 list-date-of-nesting-occurence) list-date-of-nesting-occurence
          ]
        ])
    ]
  ]


  ask feeding-patches [
    ;Depletion
    if (site-depletion)
    [
      seagrass-stock-regrowth
    ]
  ]



  ;plotting
  if display-plots
  [
    plot-remigration-interval
    plot-prenesting-migration-distance
    plot-migration-duration
    plot-number-of-nesting-females
    plot-energy-levels
    plot-mean-site-stock
  ]

  ;recording after 3000 time-step
  if (record and (ticks >= MINIMUM-STEP-BEFORE-RECORDING)) [
    set record-validated true
  ]

  ;update of the end date of the simulation
  set simulation-end-date format-date date-and-time

  tick
end

;;;; ENERGY ;;;;
;IMPORTANT : This function already take into account the TIME-STEP
;= the number of days corresponding to an single tick increment
to win-energy
  ifelse (site-depletion = true)
  [
  let energy-gain-foraging 0
  let max-seagrass-stock-avalaibility 0
  ask gt-feeding-patch [
    set max-seagrass-stock-avalaibility intake-proportion * feeding-patch-resource-level
  ]
  set energy-gain-foraging max-seagrass-stock-avalaibility
  set energy-level energy-level + energy-gain-foraging
  ];else
  [
    set energy-level energy-level + daily-food-intake-foraging * tick2time 1
  ]
end


to lose-energy [energy-expenditure]
  set energy-level energy-level - energy-expenditure * tick2time 1
end




;;;;; GTURTLES ACTIONS ;;;;
;PRENESTING MIGRATION
to prenesting-migrates

  ;loses corresponding amount of energy
  lose-energy energy-loss-migration

  ;did the gturtle reached her nesting site ?
  ;if: she didn't reach her nesting site then move ahead
  ifelse (abs (([xcor] of gt-nesting-site) - xcor) >= REACHING-SITE-DISTANCE-TOLERANCE) or (abs (([ycor] of gt-nesting-site) - ycor) >= REACHING-SITE-DISTANCE-TOLERANCE)
  [
    ;eventually 1/1000 record position
    if(record-migration and (random 500) < 1) [write-events-to-file]



    move-one-step-towards gt-nesting-site
    ;evaluate last prenesting migration distance
    ;evaluate current migration distance
    set current-migration-distance current-migration-distance + NLU2RU-dist NLU-speed
  ]
  ;else: she is at nesting site
  [
    ; end of prenesting migration

    ;if not first migration, evaluate the duration of the migration
    ;in time format
    if last-prenesting-starting-date != "" [
      set last-prenesting-duration (TODAY-DATE - last-prenesting-starting-date)

      set last-prenesting-migration-distance current-migration-distance
    ]

    ;change internal state to nesting
    set gt-internal-state "nesting"
  ]
end



;NESTING
to nests
  ;if nesting hasnt started yet
  if not nesting-started?
  [
    nesting-start
  ]

  ;loses energy for nesting
  lose-energy energy-loss-nesting

  if energy-level <= energy-level-when-nesting-starts - energy-allocated-to-nesting
  [
    ;record energy when nesting stop and write it to file
    nesting-stop

    ;Then start post nesting
    set gt-internal-state "postnesting"
    set heading target-site-heading
    set last-postnesting-starting-date TODAY-DATE

    ;reseting migration parameters
    set current-migration-distance 0
    ;reversing the direction of coast avoidance
    set gt-avoidance-side gt-avoidance-side * -1

    ;reseting the nesting started boolean
    set nesting-started? false
  ]

end

;Specific actions when nesting start
;This mainly consits of recording energy levels
to nesting-start
  ;adding one nesting turtle to the nesting site number of nesting turtle
  ; export id of turtles

  ;recording energy at arrival
  set energy-level-when-nesting-starts energy-level

  ;; records nesting dates and evaluates remigration interval
  ;adding current date to the nesting dates list
  set nesting-season-starting-dates fput TODAY-DATE nesting-season-starting-dates

  ;if it isn't the firt nesting season :
  ;evaluate the remigration interval
  if butfirst nesting-season-starting-dates != []
  [
    ;evaluate last-remigration-interval
    set last-remigration-interval first nesting-season-starting-dates - first but-first nesting-season-starting-dates

    ;to avoid memory overload
    set nesting-season-starting-dates but-last nesting-season-starting-dates
  ]

  ;nesting is now started
  set nesting-started? true

end

;Specific actions when nesting stops
;This mainly consits of recording energy levels
to nesting-stop
  ;adding one nesting turtle to the nesting site number of nesting turtle
  ; export id of turtles

  ;recording energy at leaving
  set energy-level-when-nesting-stops energy-level

  if(display-plots)[
    ;recording turtle energy levels at the nesting site
    ask gt-nesting-site [
      set list-date-of-nesting-occurence fput TODAY-DATE list-date-of-nesting-occurence
      set list-energy-level-when-nesting-stops fput [energy-level-when-nesting-stops] of myself list-energy-level-when-nesting-stops
    ]
  ]


  ;record event into file
  if record-nesting [
    write-events-to-file
  ]


end






;POST-NESTING MIGRATION
to postnesting-migrates
  ;loses energy for one day of migration
  lose-energy energy-loss-migration

  ;did the gturtle reached her foraging site ?
  ifelse (abs (([xcor] of gt-feeding-patch) - xcor) >= REACHING-SITE-DISTANCE-TOLERANCE) or (abs (([ycor] of gt-feeding-patch) - ycor) >= REACHING-SITE-DISTANCE-TOLERANCE)
  ;if not move forward
  [

    ;eventually 1/1000 record position
    if (record-migration and (random 500) < 1) [write-events-to-file]

    move-one-step-towards gt-feeding-patch

    ;evaluate current migration distance
    set current-migration-distance current-migration-distance + NLU2RU-dist NLU-speed

  ]
  ;else: she is at foraging site
  [
    ;stop postnesting
    if last-postnesting-starting-date != "" [
      set last-postnesting-duration (TODAY-DATE - last-postnesting-starting-date)

      set last-postnesting-migration-distance current-migration-distance
    ]

    ;start foraging and update the number of turtles
    set-internal-state-foraging

    set prenesting-threshold evaluate-energy-cycle

    ;record the visit
    if (record-validated) [
      let value (array:item array:item foraging-nesting-turtle-visits nestix feedix) + 1
      array:set array:item foraging-nesting-turtle-visits nestix feedix value
    ]
  ]
end


;FEEDING
to feeds

  ;wins energy for one day of foragingpostnesting-migrates
  win-energy


  ;record the foraging site time usage
  if (record-validated) [
    let value (array:item array:item foraging-nesting-time-usage nestix feedix) + tick2time 1
    array:set array:item foraging-nesting-time-usage nestix feedix value
  ]

  ;if the turtles needs to search for a new site
  ifelse (foraging-migration = TRUE and foraging-migration-trigger foraging-migration-decision = TRUE)
  [
    ;Then start searching migration
    set-internal-state-foraging-migration

    set current-migration-distance 0
    set last-foraging-migration-starting-date TODAY-DATE
    set gt-avoidance-side 0

    allocate-new-feeding-patch gt-feeding-patch allocate-new-feeding-patch-method

    ;record the change
    if (record-validated) [
      let value (array:item array:item foraging-nesting-turtle-chosen nestix feedix) + 1
      array:set array:item foraging-nesting-turtle-chosen nestix feedix value
    ]
  ]
  ;else check whether i should start nesting
  [
    if (prenesting-trigger = TRUE)
    [
      ;Then start post nesting
      set-internal-state-prenesting
      set heading target-site-heading
      set last-prenesting-starting-date TODAY-DATE
      set current-migration-distance 0
      set gt-avoidance-side gt-avoidance-side * -1
    ]
  ]


end


;SUB functions to change internal state
to set-internal-state-foraging
   set gt-internal-state "feeding"
   ask gt-feeding-patch [
     set feeding-patch-nturtles feeding-patch-nturtles + 1]
end

to set-internal-state-prenesting
   set gt-internal-state "prenesting"
   ask gt-feeding-patch [set feeding-patch-nturtles feeding-patch-nturtles - 1]
end

to set-internal-state-foraging-migration
   set gt-internal-state "foraging-migration"
   ask gt-feeding-patch [
     set feeding-patch-nturtles feeding-patch-nturtles - 1
       ]
end



;;SUB-functions of nests
to-report evaluate-total-nesting-energy-expenditure
  report nesting-allocation-strategy * max-nesting-duration * energy-loss-nesting
  ;in energy unit
end



;sub fonction of feeds
;Allocates a new foraging site
;site correspond to the starting sites and it can be either :
; - gt-feeding-patch if the turtle start from a foraging site
; - gt-nesting-site if the turtle start form a nesting site (eg; initialization of the program)
to allocate-new-feeding-patch [start-site method]

  if (N-GTURTLES = 1)
  [
    ;here we use carefully because the foraging site may not exists yet
    carefully[ask gt-feeding-patch [color-feeding-patch]][]
  ]

  ifelse (method = "decreasing-exponential")
  [
    let expo-values [descreasing-exponential-probability-for-other-feeding-patches] of start-site

    ;we transform the distance list to a list of pro
    let alea random-float 1000

    let acceptable-value ""

    foreach reverse sort expo-values [
      if(? >= alea) [set acceptable-value ?]
    ]

    let picked-site position acceptable-value expo-values

    if (gt-feeding-patch = feeding-patch (N-NESTING-SITES + picked-site))
    [
      print("Error: Identical foraging site allocation")
    ]


    set gt-feeding-patch feeding-patch (N-NESTING-SITES + picked-site)

  ]
  [
    let other-feeding-patches []
    ask gt-feeding-patch [set other-feeding-patches other feeding-patches]
    set gt-feeding-patch one-of other-feeding-patches
  ]


  set heading towards gt-feeding-patch

  if (N-GTURTLES = 1)
  [
    ask gt-feeding-patch [set color yellow]
  ]

end




;Migrating between two foraging sites
to between-feeding-patches-migrates
  ;for now there should be nothing much different than the postnesting migration

  ;loses energy for one day of migration
  lose-energy energy-loss-migration

  ;did the gturtle reached her foraging site ?
  ifelse (abs (([xcor] of gt-feeding-patch) - xcor) >= REACHING-SITE-DISTANCE-TOLERANCE) or (abs (([ycor] of gt-feeding-patch) - ycor) >= REACHING-SITE-DISTANCE-TOLERANCE)
  ;if not move forward
  [

    move-one-step-towards gt-feeding-patch

    set current-migration-distance current-migration-distance + NLU2RU-dist NLU-speed

  ]
  ;else: she is at foraging site
  [
    ;stop foraging migration

    ;print "Very much abnormal and I dont understand anything"
    if last-postnesting-starting-date != "" [
      set last-foraging-migration-duration (TODAY-DATE - last-foraging-migration-starting-date)

      set last-foraging-migration-distance current-migration-distance
    ]

    ;start foraging
    set-internal-state-foraging

    ;record the visit
    if (record-validated) [
      let value (array:item array:item foraging-nesting-turtle-visits nestix feedix) + 1
      array:set array:item foraging-nesting-turtle-visits nestix feedix value
    ]
  ]

end



;;;;;

to-report nestix
    report [nesting-site-id] of gt-nesting-site
end

to-report feedix
    report [feeding-patch-id] of gt-feeding-patch
end


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;



;MOVEMENT
;facing the target (nesting or foraging) site
to-report target-site-heading
  let heading-target heading

  if gt-internal-state = "prenesting" or gt-internal-state = "feeding"
  [
    carefully [set heading-target towards gt-nesting-site] [show "sedentary turtle"]
  ]
  if gt-internal-state = "postnesting" or gt-internal-state = "nesting" or gt-internal-state = "foraging-migration"
  [
    carefully [set heading-target towards gt-feeding-patch] [show "sedentary turtle"]
  ]

  report heading-target
end




;Migration movement

to move-one-step-towards [target-site]
  ifelse sea-currents[
    move-one-step-towards-with-currents target-site
  ]
  [
    move-one-step-towards-without-currents target-site
  ]

end




to move-one-step-towards-without-currents [target-site]


  ;the rotation angle to test
  let angle-step 20
  let angle-checked 0
  let good-heading 0

  ; If I am facing the wall
  ; I try to avoid it to the right
  ; I turn right until I found no coast then I move forward

  ;if I am not facing the limit of the world
  ifelse patch-ahead NLU-speed != nobody
    [
      let patch-ahead-isfree? 0

      ;if I am facing the wall = the shore

      ifelse is-ground? patch-ahead NLU-speed
      [
        set patch-ahead-isfree? false

        ;If not done yet, decide side for avoidance
        if gt-avoidance-side = 0
        [
          ;;On which side to avoid the coast

          ;The turtle will try to avoid the coast to the left or to the right
          ;She will choose the direction that require the minimum rotating angle
          ;from her actual navigation direction
          let angle-to-the-left heading
          let angle-to-the-right heading


          ;testing to the left
          while [not patch-ahead-isfree?] [
            set angle-to-the-left (angle-to-the-left - angle-step)

            ifelse patch-at-heading-and-distance angle-to-the-left NLU-speed != nobody
              [set patch-ahead-isfree? (not is-ground? patch-at-heading-and-distance angle-to-the-left NLU-speed)
            ];
              [set patch-ahead-isfree? false]


          ]



          set patch-ahead-isfree? false

          ;testing to the right
          while [not patch-ahead-isfree?] [
            set angle-to-the-right (angle-to-the-right + angle-step)

            ifelse patch-at-heading-and-distance angle-to-the-right NLU-speed != nobody
            [set patch-ahead-isfree? (not is-ground? patch-at-heading-and-distance angle-to-the-right NLU-speed)];
            [set patch-ahead-isfree? false]

          ]

          set patch-ahead-isfree? false



          let left-change abs (heading - angle-to-the-left)
          let right-change abs (heading - angle-to-the-right)

          ;          print word "left " left-change
          ;          print word "right " right-change
          ;

          ; Choice of the minimum deviation angle
          ; remember gt avoidance mode : 1=Clockwise or Right  -1=Anticlockwise or Left
          ifelse left-change > right-change
          [set gt-avoidance-side 1]
          [ifelse left-change < right-change
            [set gt-avoidance-side -1]
            [set gt-avoidance-side (random 1) * 2 - 1]
          ]
        ]

        ;Avoiding the coast
        while [not patch-ahead-isfree?] [
          set heading (heading + angle-step * gt-avoidance-side)

;          ifelse patch-ahead NLU-speed != nobody AND ([pcolor] of patch-ahead NLU-speed != PCOLOR-OF-GROUND)
          ifelse patch-ahead NLU-speed != nobody AND (not is-ground? patch-ahead NLU-speed)
          [set patch-ahead-isfree? true];
          [
            set patch-ahead-isfree? false
            ;set heading (heading - angle-step * gt-avoidance-side)
          ]
        ]


        ;fd NLU-speed

      ]
      ; otherwise if I am not facing the wall
      ; I turn left as long as I can
      ; But not further that the direction of my site
      ; and I move forward
      [
        ;next line necessary because of world limit
        set patch-ahead-isfree? true

        ;following the coast

        while [patch-ahead-isfree? and not almost-heading-without-currents? target-site angle-step and gt-avoidance-side != 0]
        [
          set heading (heading - angle-step * gt-avoidance-side)
          ifelse (patch-ahead NLU-speed != nobody) AND (not is-ground? patch-ahead NLU-speed)
          [
            set patch-ahead-isfree? true
          ]
          [
            set patch-ahead-isfree? false
            set heading (heading + angle-step * gt-avoidance-side)
          ]

        ]


        ; should I change mode
        ; = did the coast made me change my direction toward
        if almost-heading-without-currents? target-site angle-step AND (not is-ground? (patch-at-heading-and-distance (towards target-site) NLU-speed))
        [
          set heading towards target-site
        ]
      ]


    ]
    [ ;else if there is no patch ahead of me (=outside bound)
      ;i should rebound and avoid the coast to the other side
      set heading heading + 180
      set gt-avoidance-side -1 * gt-avoidance-side
    ]


  fd NLU-speed

end


to move-one-step-towards-with-currents [target-site]

  let angle-step 20
  let angle-checked 0
  let good-heading 0


  ;;fakeposition of target that takes currents into account
  let fake-target-x xcor + dx * NLU-speed + NLU-xcurrents
  let fake-target-y ycor + dy * NLU-speed + NLU-ycurrents

  ;;changing turtle heading towards fake target
  facexy fake-target-x fake-target-y

  ;;changing speed according to the currents
  let NLU-speed-with-currents distancexy fake-target-x fake-target-y



  ; If I am facing the wall
  ; I try to avoid it to the right
  ; I turn right until I found no coast then I move forward

  ;if I am not facing the limit of the world
  ifelse patch-ahead NLU-speed-with-currents != nobody
    [
      let patch-ahead-isfree? 0

      ;if I am facing the wall = the shore
      ifelse is-ground? patch-ahead NLU-speed-with-currents
      [
        set patch-ahead-isfree? false

        ;If not done yet, decide side for avoidance
        if gt-avoidance-side = 0
        [
          ;;On which side to avoid the coast

          ;The turtle will try to avoid the coast to the left or to the right
          ;She will choose the direction that require the minimum rotating angle
          ;from her actual navigation direction
          let angle-to-the-left heading
          let angle-to-the-right heading

          ;print "decision process in progress"

          ;testing to the left
          while [not patch-ahead-isfree?] [
            set angle-to-the-left (angle-to-the-left - angle-step)

            ifelse patch-at-heading-and-distance angle-to-the-left NLU-speed-with-currents != nobody
              [set patch-ahead-isfree? (not is-ground? patch-at-heading-and-distance angle-to-the-left NLU-speed-with-currents)
            ];
              [set patch-ahead-isfree? false]


          ]



          set patch-ahead-isfree? false

          ;testing to the right
          while [not patch-ahead-isfree?] [
            set angle-to-the-right (angle-to-the-right + angle-step)

            ifelse patch-at-heading-and-distance angle-to-the-right NLU-speed-with-currents != nobody
            [set patch-ahead-isfree? (not is-ground? patch-at-heading-and-distance angle-to-the-right NLU-speed-with-currents)];
            [set patch-ahead-isfree? false]

          ]

          set patch-ahead-isfree? false



          let left-change abs (heading - angle-to-the-left)
          let right-change abs (heading - angle-to-the-right)

          ;          print word "left " left-change
          ;          print word "right " right-change
          ;

          ; Choice of the minimum deviation angle
          ; remember gt avoidance mode : 1=Clockwise or Right  -1=Anticlockwise or Left
          ifelse left-change > right-change
          [set gt-avoidance-side 1]
          [ifelse left-change < right-change
            [set gt-avoidance-side -1]
            [set gt-avoidance-side (random 1) * 2 - 1]
          ]
        ]

        ;Avoiding the coast
        while [not patch-ahead-isfree?] [
          set heading (heading + angle-step * gt-avoidance-side)

;          ifelse patch-ahead NLU-speed != nobody AND ([pcolor] of patch-ahead NLU-speed != PCOLOR-OF-GROUND)
          ifelse patch-ahead NLU-speed-with-currents != nobody AND (not is-ground? patch-ahead NLU-speed-with-currents)
          [set patch-ahead-isfree? true];
          [
            set patch-ahead-isfree? false
          ]
        ]


        ;fd NLU-speed

      ]
      ; otherwise if I am not facing the wall
      ; I turn left as long as I can
      ; But not further that the direction of my site
      ; and I move forward
      [
        ;next line necessary because of world limit
        set patch-ahead-isfree? true

        ;following the coast
        while [patch-ahead-isfree? and not almost-heading? fake-target-x fake-target-y angle-step and gt-avoidance-side != 0]
        [
          set heading (heading - angle-step * gt-avoidance-side)
          ifelse (patch-ahead NLU-speed-with-currents != nobody) AND (not is-ground? patch-ahead NLU-speed-with-currents)
          [
            set patch-ahead-isfree? true
          ]
          [
            set patch-ahead-isfree? false
            set heading (heading + angle-step * gt-avoidance-side)
          ]

        ]
        ;fd NLU-speed



        ;print "follow"
        ; should I change mode
        ; = did the coast made me change my direction toward
;        if almost-heading? target-site angle-step AND ([pcolor] of (patch-at-heading-and-distance (towards target-site) NLU-speed) != PCOLOR-OF-GROUND)
        if almost-heading? fake-target-x fake-target-y angle-step AND (not is-ground? (patch-at-heading-and-distance (towardsxy fake-target-x fake-target-y) NLU-speed-with-currents))
        ;if abs(heading - towards target-site) < angle-step AND ([pcolor] of (patch-at-heading-and-distance (towards target-site) NLU-speed) != PCOLOR-OF-GROUND)
        [
          set heading towardsxy fake-target-x fake-target-y
        ]
        ;    ]
      ]


    ]
    [ ;else if there is no patch ahead of me (=outside bound)
      ;i should rebound and avoid the coast to the other side
      set heading heading + 180
      set gt-avoidance-side -1 * gt-avoidance-side
    ]

    fd NLU-speed-with-currents
    face target-site


end




to-report almost-heading-without-currents? [target-site angle-step]
  ifelse (target-site = -999)
  [
    report false
  ]
  [
    report (abs(heading - towards target-site) < angle-step)
  ]
end


to-report almost-heading? [target-x target-y angle-step]
    report (abs(heading - towardsxy target-x target-y) < angle-step)
end


to-report NLU-xcurrents
;  see R-script for equations
;  #u=(278.8843*r/255-93.14064)*0.036

  report RU2NLU-dist ((first [pcolor] of patch-here * 278.8843 / 255 - 93.14064) * 0.036 * 24) * tick2time 1
end


to-report NLU-ycurrents
; #v=(276.6717*b-108.4809)*0.036
  report RU2NLU-dist ((first reverse [pcolor] of patch-here * 276.6717 / 255 - 108.4809) * 0.036 * 24) * tick2time 1
end



;;;; NESTING MIGRATION CYCLE TRIGGER ;;;
;this function decides when the turtle is able to start the migration for nesting
to-report prenesting-trigger
  ; for now it is a simple floor that let the turtle start its migration
  ; a very high floor will ensure that the turtle won't migrate too far
  let pull-the-trigger FALSE

  if (prenesting-start-method = "threshold")
  [
    if energy-level > minimal-energy-for-prenesting and (nesting-season-starting-dates = [] or TODAY-DATE - first nesting-season-starting-dates > minimal-remigration-interval)
    [
      set pull-the-trigger TRUE
    ]
  ]
  if (prenesting-start-method = "distance-dependant")
  [

    if energy-level >= prenesting-threshold and (nesting-season-starting-dates = [] or TODAY-DATE - first nesting-season-starting-dates > minimal-remigration-interval)
    [
      set pull-the-trigger TRUE
    ]

  ]


  report pull-the-trigger
end


;evaluate the total cost of the cycle
to-report evaluate-energy-cycle
  ;cost of migration
  let my-nesting-site gt-nesting-site
  let distance-from-nesting-site [distance my-nesting-site] of gt-feeding-patch
  let migration-expenditure 2 * energy-loss-migration * distance-from-nesting-site / NLU-speed * tick2time 1

  ;total energy is equal to energy for migration + energy for nesting
  let cycle-energy-expenditure migration-expenditure + energy-allocated-to-nesting

  report cycle-energy-expenditure
end

to-report foraging-migration-trigger [method]
  let pull-the-trigger FALSE


  ifelse method = "strategy-around-threshold"
  [
     let feeding-patch-leaving-slope feeding-patch-leaving-threshold / 5
     ;the probability of leaving the patch
     let pleave (1 - 1 / (1 + exp(1 / feeding-patch-leaving-slope *(- [feeding-patch-resource-level] of gt-feeding-patch + feeding-patch-leaving-threshold)))) / 1000 * (1 - foraging-fidelity-strategy)

     if random-float 1 < pleave  [
       set pull-the-trigger TRUE
     ]

  ]
  [
    ifelse method = "strategy-below-threshold"
    [
      if [feeding-patch-resource-level] of gt-feeding-patch <= feeding-patch-leaving-threshold [
        if foraging-fidelity-strategy > random-float 1 [
          set pull-the-trigger TRUE
        ]
      ]
    ]
    [
      ;random with high probability

      let x random 1000

      if foraging-fidelity-strategy > random-float 1 [set pull-the-trigger TRUE]
    ]
  ]



  report pull-the-trigger

end



to seagrass-stock-regrowth
  ;energy-gain-foraging
  let energy-gain-foraging patch-regrowth-rate * (1 - feeding-patch-resource-level / maximum-feeding-patch-resource-level)

  ;loss
  let loss intake-proportion * feeding-patch-nturtles

  ;total
  set feeding-patch-resource-level feeding-patch-resource-level * (1 + (energy-gain-foraging - loss) * tick2time 1)

  ;perturbation
  if (perturbation-type != "none")
  [
    set feeding-patch-resource-level feeding-patch-resource-level * (1 - perturbation * tick2time 1)
  ]

  color-feeding-patch
end


to color-feeding-patch
  set color scale-color green feeding-patch-resource-level 0  maximum-feeding-patch-resource-level
end


;;; PERTURBATIONS ;;;
to-report perturbation
  ;if none :
  let loss 0

  let energy-gain-foraging patch-regrowth-rate * (1 - feeding-patch-resource-level / maximum-feeding-patch-resource-level)

;  if perturbation-type = "distance-dependant"
  let distance-to-perturbation distancexy lon2xcor perturbation-x lat2ycor perturbation-y

  if perturbation-type = "latitude-dependant"
  [
    set distance-to-perturbation distancexy xcor lat2ycor perturbation-y
  ]

    if perturbation-type = "longitude-dependant"
  [
    set distance-to-perturbation distancexy lon2xcor perturbation-x ycor
  ]


  if(distance-to-perturbation < RU2NLU-dist perturbation-range)[

    ;perturbation is proportional to the distance of perturbation center
    set loss perturbation-intensity * patch-regrowth-rate * RU2NLU-dist perturbation-range / distance-to-perturbation
  ]


  report loss


end






;;;; COLOR OF GROUND ;;;
to-report is-ground? [thepatch]
  report (first but-first [pcolor] of thepatch > 0)
end






;;;; UNITS CONVERSION ;;;


;converts longitude data to world coordinates
to-report lon2xcor [lon]
  report  (lon - MIN-LON) * max-pxcor / (MAX-LON - MIN-LON)
end


;converts latitude data to world coordinates
to-report lat2ycor [lat]
  report  (lat - MIN-LAT) * max-pycor / (MAX-LAT - MIN-LAT)
end


;converts  x world coordinates to longitude data
to-report xcor2lon [thexcor]
  report  thexcor / max-pxcor * (MAX-LON - MIN-LON) + MIN-LON
end


;converts  x world coordinates to longitude data
to-report ycor2lat [theycor]
  report  theycor / max-pycor * (MAX-LAT - MIN-LAT) + MIN-LAT
end


;converts  NLU distance in pixel to RU distance in Km
to-report NLU2RU-dist [NLU-dist]
  report precision ((MAX-LAT - MIN-LAT) / max-pycor * 111 * NLU-dist) 2
end

to-report RU2NLU-dist [RU-dist]
  report precision (max-pycor / ((MAX-LAT - MIN-LAT) * 111)  * RU-dist) 2
end



;calculate distance  between 2 points in map unit (km) from xcor and ycor
to-report map-distance[xcor1 ycor1 xcor2 ycor2]
  let lon1 xcor2lon xcor1
  let lat1 ycor2lat ycor1

  let lon2 xcor2lon xcor2
  let lat2 ycor2lat ycor2

  report 2 * asin(sqrt((sin((lat1 - lat2) / 2)) ^ 2 + cos(lat1) * cos(lat2) * (sin((lon1 - lon2) / 2)) ^ 2)) * 6366 * pi / 180
  ;6366kms is the approximate perimeter of earth at equator
end


;calculate the distance (in km) corresponding to one pixel :
to pixel-size-in-map-distance
  let xcor1 0
  let ycor1 0
  let xcor21 10
  let ycor21 0
  let xcor22 0
  let ycor22 10


  let x-pixel-size (map-distance xcor1 ycor1 xcor21 ycor21) / 10
  let y-pixel-size (map-distance xcor1 ycor1 xcor22 ycor22) / 10


  output-type "Real dimensions : one pixel is " output-type precision x-pixel-size 2
  output-type "x"output-type precision y-pixel-size 2 output-print "km"



  let approx-x-pixel-size NLU2RU-dist 1
  let approx-y-pixel-size NLU2RU-dist 1

end


;converts ticks to time
to-report tick2time [thetick]
  report thetick * TIME-STEP
end

;convert time to tick
to-report time2tick [thetime]
  report thetime / TIME-STEP
end

;format date and time
to-report format-date [date]
  let month 99
  let year 9999

  ifelse(not running-on-supercomp)[
  let months ["Jan" "Feb" "Mar" "Apr" "May" "Jun" "Jul" "Aug" "Sep" "Oct" "Nov" "Dec"]
  set month (word (position substring date-and-time 19 22 months + 1))

  set year substring date-and-time 23 27
  ]

  ;;next bloc to be used only if the date time is buggy
  [
  let months ["jan" "feb" "mar" "avr" "mai" "jun" "jul" "aôu" "sep" "oct" "nov" "déc"]
  set month (word (position substring date-and-time 19 22 months + 1))

  set year substring date-and-time 23 27
  ]

  if (length month = 1) [set month word "0" month]

  let hour read-from-string substring date-and-time 0 2
  if (hour < 12 and hour > 0 and substring date-and-time 13 14 = "P")[set hour hour + 12]
  if (length (word month) = 1) [set month word "0" month]


  report (word year month substring date-and-time 16 18 hour substring date-and-time 3 5 substring date-and-time 6 8 substring date-and-time 9 12)
end



;;;; PLOTS ;;;;
;;
to plot-remigration-interval
  set-current-plot "plot-of-remigration-interval"
  set-current-plot-pen "over-last-event"
  let last-remigration-interval-in-years []
  ask gturtles [
    if (last-remigration-interval != "")
    [
      set last-remigration-interval-in-years fput (last-remigration-interval / 365) last-remigration-interval-in-years
    ]
  ]
  histogram last-remigration-interval-in-years
end



to plot-prenesting-migration-distance
  set-current-plot "plot-of-prenesting-migration-distance"
  set-current-plot-pen "last-prenesting"
  histogram [last-prenesting-migration-distance] of gturtles
  set-current-plot-pen "last-postnesting"
  histogram [last-postnesting-migration-distance] of gturtles
end


to plot-migration-duration
  set-current-plot "plot-of-migration-duration"
  set-current-plot-pen "prenesting-duration"
  histogram [last-prenesting-duration] of gturtles

 ; if not ([last-prenesting-duration] of gturtles = "") [
;  show mean ([last-prenesting-duration] of gturtles)]

  set-current-plot-pen "postnesting-duration"
  histogram [last-postnesting-duration] of gturtles
end


to plot-number-of-nesting-females
  set-current-plot "plot-of-nesting-females-number"
  foreach sort nesting-sites [
    ask nesting-sites [
    let site-id word "site" (who + 1)
    set-current-plot-pen site-id
    set-plot-pen-color color
    plot ((length filter [TODAY-DATE - ? <= number-of-days-of-integration] list-date-of-nesting-occurence))
  ]]
end



to plot-energy-levels
  set-current-plot "plot-of-mean-energy"
  set-plot-x-range min [energy-level] of gturtles max [energy-level] of gturtles + 1
  set-current-plot-pen "total-distribution"
  histogram [energy-level] of gturtles



  ask nesting-sites
  [
    let site-id word "site" (who + 1)


    ;if the list of energy level is not empty
    if (list-energy-level-when-nesting-stops != [])
    [

      let partial-list-energy-level-when-nesting-stops list-energy-level-when-nesting-stops
      (foreach list-date-of-nesting-occurence list-energy-level-when-nesting-stops
        [
          if (number-of-days-of-integration <= (TODAY-DATE - ?1))
            [
              set partial-list-energy-level-when-nesting-stops remove-item (position ?2 list-energy-level-when-nesting-stops) list-energy-level-when-nesting-stops
            ]
        ])

      if (partial-list-energy-level-when-nesting-stops != [])
      [
        set-current-plot "plot-of-energy-at-nesting-sites"
        set-plot-x-range min partial-list-energy-level-when-nesting-stops max partial-list-energy-level-when-nesting-stops + 1
        set-current-plot-pen site-id
        set-plot-pen-color color
        histogram partial-list-energy-level-when-nesting-stops


        if (site-id = site-to-plot)
        [
          set-current-plot "distribution-of-energy-at-nesting-sites"
          set-plot-x-range (min partial-list-energy-level-when-nesting-stops) (max partial-list-energy-level-when-nesting-stops + 1)
          set-current-plot-pen "energy-histogram"
          set-plot-pen-color color
          histogram partial-list-energy-level-when-nesting-stops
          ;histogram list-energy-level-when-nesting-starts

        ]

        set-current-plot "plot-of-reproductive-potential"
        set-current-plot-pen site-id
        set-plot-pen-color color
        plot (mean partial-list-energy-level-when-nesting-stops) * length partial-list-energy-level-when-nesting-stops
      ]


    ]


  ]
end

to plot-mean-site-stock
  set-current-plot "histogram-of-site-stock"
  set-current-plot-pen "histogram-of-site-stock"
  set-plot-x-range (min [feeding-patch-resource-level] of feeding-patches) (max [feeding-patch-resource-level] of feeding-patches + 1)
  histogram [feeding-patch-resource-level] of feeding-patches

  set-current-plot "evolution-of-mean-site-stock"
  set-current-plot-pen "mean-site-stock"
  plot mean [feeding-patch-resource-level] of feeding-patches
end



;;;;;;;;;;;;;;;;  WRITING FILES ;;;;;;;;;;;;;;;;;;;;;;;;

to write-events-file-headers
    ;turtle id
    file-type "TURTLE_ID"
    file-type " "

    ;nesting siteid
    file-type "NEST_ID"
    file-type " "

    ;position date
    file-type "T_DAYS"
    file-type " "

    ;energy at position
    file-type "E_LEVEL"
    file-type " "

    ;nesting allocation strategy
    file-type "NEST_STRATEGY"
    file-type " "

    ;foraging siteid
    file-type "FEED_ID"
    file-type " "

    ;foraging site strategy
    file-type "FEED_STRATEGY"
    file-type " "

    ;post or prenesting
    file-type "TURTLE_MODE"
    file-type " "

    ;longitude
    file-type "LONGITUDE"
    file-type " "

    ;latitude
    file-print "LATITUDE"
end


to write-events-file-setup

    ;turtle id
    file-type who
    file-type " "

    ;nesting siteid
    file-type [nesting-site-id] of gt-nesting-site
    file-type " "

    ;nesting date
    file-type precision TODAY-DATE 2
    file-type " "

    ;energy at start of nesting
    file-type precision energy-level 2
    file-type " "

    ;nesting allocation strategy
    file-type nesting-allocation-strategy
    file-type " "

    ;foraging siteid
    file-type [feeding-patch-id] of gt-feeding-patch
    file-type " "

    ;foraging site strategy
    file-type foraging-fidelity-strategy
    file-type " "

    ;post or prenesting or nesting
    file-type mode-numeric
    file-type " "

    ;longitude
    file-type precision (xcor2lon xcor) 3
    file-type " "

    ;latitude
    file-print precision (ycor2lat ycor) 3


end


to write-events-to-file

    ;turtle id
    file-type who
    file-type " "

    ;nesting siteid
    file-type [nesting-site-id] of gt-nesting-site
    file-type " "

    ;position date
    file-type precision TODAY-DATE 2
    file-type " "

    ;energy at position or after nesting
    file-type precision energy-level 2
;    file-type precision energy-level-when-nesting-stops 2
    file-type " "

    ;nesting allocation strategy
    file-type nesting-allocation-strategy
    file-type " "

    ;foraging siteid
    file-type [feeding-patch-id] of gt-feeding-patch
    file-type " "

    ;foraging site strategy
    file-type foraging-fidelity-strategy
    file-type " "

    ;post or prenesting or nesting
    file-type mode-numeric
    file-type " "

    ;longitude
    file-type precision (xcor2lon xcor) 3
    file-type " "

    ;latitude
    file-print precision (ycor2lat ycor) 3

    ;file-close
end


to-report mode-numeric
  ifelse gt-internal-state = "prenesting" [report -1]
      [ifelse gt-internal-state = "postnesting" [report 1]
           [ifelse gt-internal-state = "nesting" [report 2]
           [report 0]]]
end



to write-files
  if movie [movie-close]

  if record-migration or record-nesting [file-close]

  if record-validated [
  write-usage-array-to-file foraging-nesting-time-usage (word "../results/" simulation-start-date "_" behaviorspace-run-number "_time_usage.txt")
  write-usage-array-to-file foraging-nesting-turtle-visits (word "../results/" simulation-start-date "_" behaviorspace-run-number "_visit.txt")
  write-usage-array-to-file foraging-nesting-turtle-chosen (word "../results/" simulation-start-date "_" behaviorspace-run-number "_new_visit.txt")
  print "files written"
  ]

  print "1 sim ended"
end


to write-usage-array-to-file [usage-array filename]
  carefully [file-delete filename][]

  file-open filename
  foreach array:to-list usage-array [
    foreach array:to-list ? [
      file-type ?
      file-type " "
      ]
    file-print ""
  ]
  file-close
end





;;;;;;;;;;;;;;;;; PROFILER ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
to run-profiler
  setup                  ;; set up the model
  profiler:start         ;; start profiling
  repeat 2000 [ go ]       ;; run something you want to measure
  profiler:stop          ;; stop profiling

  let myreport profiler:report  ;; view the results
  print myreport
  file-open (word "../results/" simulation-start-date ".txt")
  file-type myreport
  file-close
  profiler:reset        ;; clear the data
end

@#$#@#$#@
GRAPHICS-WINDOW
8
10
585
618
-1
-1
1.0
1
10
1
1
1
0
0
0
1
0
566
0
576
1
1
1
ticks
30.0

BUTTON
674
487
829
526
Setup Turtles and Sites
setup-turtles-and-sites
NIL
1
T
OBSERVER
NIL
T
NIL
NIL
1

INPUTBOX
589
102
813
162
N-GTURTLES
100
1
0
Number

BUTTON
594
535
667
626
NIL
GO
T
1
T
OBSERVER
NIL
G
NIL
NIL
1

PLOT
20
1755
608
2082
plot-of-remigration-interval
remigration-interval
frequency
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"overall" 0.1 0 -2674135 true "" ""
"over-last-event" 0.1 1 -16777216 true "" ""

INPUTBOX
451
1303
644
1363
minimal-energy-for-prenesting
0
1
0
Number

INPUTBOX
29
1302
216
1362
energy-loss-migration
1
1
0
Number

INPUTBOX
22
1454
214
1514
energy-loss-nesting
5
1
0
Number

INPUTBOX
378
742
552
802
daily-food-intake-foraging
1500
1
0
Number

PLOT
636
1757
1202
2083
plot-of-prenesting-migration-distance
NIL
NIL
0.0
6000.0
0.0
25.0
true
true
"" ""
PENS
"last-prenesting" 200.0 1 -13345367 true "" ""
"last-postnesting" 200.0 1 -2674135 true "" ""

PLOT
22
2082
609
2382
plot-of-migration-duration
NIL
NIL
0.0
60.0
0.0
10.0
true
true
"" ""
PENS
"prenesting-duration" 1.0 1 -13345367 true "" ""
"postnesting-duration" 1.0 1 -2674135 true "" ""

BUTTON
674
441
828
480
Setup Map
setup-map
NIL
1
T
OBSERVER
NIL
M
NIL
NIL
1

BUTTON
593
441
668
527
Setup All
setup
NIL
1
T
OBSERVER
NIL
A
NIL
NIL
1

OUTPUT
875
153
1292
294
13

MONITOR
589
10
697
55
Elapsed time
precision TODAY-DATE 0
17
1
11

PLOT
635
2083
1202
2378
plot-of-nesting-females-number
time
number-of-nesting-females
0.0
10.0
0.0
3.0
true
true
"" ""
PENS
"site1" 1.0 0 -16777216 true "" ""
"site2" 1.0 0 -16777216 true "" ""
"site3" 1.0 0 -16777216 true "" ""
"site4" 1.0 0 -16777216 true "" ""
"site5" 1.0 0 -16777216 true "" ""
"site6" 1.0 0 -16777216 true "" ""
"site7" 1.0 0 -16777216 true "" ""
"site8" 1.0 0 -16777216 true "" ""
"site9" 1.0 0 -16777216 true "" ""
"site10" 1.0 0 -16777216 true "" ""
"site11" 1.0 0 -16777216 true "" ""
"site12" 1.0 0 -16777216 true "" ""
"site13" 1.0 0 -16777216 true "" ""
"site14" 1.0 0 -16777216 true "" ""

SLIDER
1210
2097
1243
2366
number-of-days-of-integration
number-of-days-of-integration
1
60
51
1
1
days
VERTICAL

SWITCH
592
399
818
432
record
record
0
1
-1000

SWITCH
592
360
818
393
keep-tracks
keep-tracks
1
1
-1000

SWITCH
18
1715
165
1748
display-plots
display-plots
0
1
-1000

INPUTBOX
248
1453
434
1513
minimal-remigration-interval
0
1
0
Number

TEXTBOX
384
1483
418
1501
days
12
0.0
1

TEXTBOX
656
31
686
49
days\n
12
0.0
1

BUTTON
673
535
827
573
Profiler
run-profiler
NIL
1
T
OBSERVER
NIL
P
NIL
NIL
1

PLOT
24
2393
609
2702
plot-of-mean-energy
NIL
NIL
300.0
900.0
0.0
10.0
true
false
"" ""
PENS
"total-distribution" 5.0 1 -16777216 true "" ""
"site1" 1.0 0 -2674135 true "" ""
"site2" 1.0 0 -5825686 true "" ""
"site3" 1.0 0 -6459832 true "" ""
"site4" 1.0 0 -13345367 true "" ""
"total-evolution" 1.0 0 -16777216 true "" ""

PLOT
634
2394
1204
2700
plot-of-energy-at-nesting-sites
NIL
NIL
300.0
900.0
0.0
10.0
true
false
"" ""
PENS
"total" 1.0 0 -16777216 true "" ""
"site1" 5.0 0 -16777216 true "" ""
"site2" 5.0 0 -16777216 true "" ""
"site3" 5.0 0 -16777216 true "" ""
"site4" 5.0 0 -16777216 true "" ""
"site5" 5.0 0 -16777216 true "" ""
"site6" 1.0 0 -16777216 true "" ""
"site7" 1.0 0 -16777216 true "" ""
"site8" 1.0 0 -16777216 true "" ""
"site9" 1.0 0 -16777216 true "" ""
"site10" 1.0 0 -16777216 true "" ""
"site11" 1.0 0 -16777216 true "" ""
"site12" 1.0 0 -16777216 true "" ""
"site13" 1.0 0 -16777216 true "" ""
"site14" 1.0 0 -16777216 true "" ""

PLOT
24
2710
610
3044
distribution-of-energy-at-nesting-sites
NIL
NIL
300.0
900.0
0.0
10.0
true
false
"" ""
PENS
"energy-histogram" 5.0 1 -16777216 true "" ""

CHOOSER
246
2732
384
2777
site-to-plot
site-to-plot
"site1" "site2" "site3" "site4" "site5" "site6" "site7"
3

SWITCH
23
1043
260
1076
foraging-migration
foraging-migration
0
1
-1000

SWITCH
18
695
183
728
site-depletion
site-depletion
1
1
-1000

PLOT
27
3377
595
3704
histogram-of-site-stock
NIL
NIL
0.0
1010.0
0.0
1.0
true
false
"" ""
PENS
"histogram-of-site-stock" 1.0 1 -16777216 true "" ""

INPUTBOX
197
742
364
802
intake-proportion
1.0E-4
1
0
Number

CHOOSER
231
1161
517
1206
allocate-new-feeding-patch-method
allocate-new-feeding-patch-method
"decreasing-exponential" "random"
0

SLIDER
522
1162
823
1195
feeding-patch-allocation-exponent
feeding-patch-allocation-exponent
0
20
20
1
1
NIL
HORIZONTAL

PLOT
24
3049
612
3366
plot-of-reproductive-potential
NIL
NIL
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"site1" 1.0 0 -16777216 true "" ""
"site2" 1.0 0 -16777216 true "" ""
"site3" 1.0 0 -16777216 true "" ""
"site4" 1.0 0 -16777216 true "" ""
"site5" 1.0 0 -16777216 true "" ""
"site6" 1.0 0 -16777216 true "" ""
"site7" 1.0 0 -16777216 true "" ""
"site8" 1.0 0 -16777216 true "" ""
"site9" 1.0 0 -16777216 true "" ""
"site10" 1.0 0 -16777216 true "" ""
"site11" 1.0 0 -16777216 true "" ""
"site12" 1.0 0 -16777216 true "" ""
"site13" 1.0 0 -16777216 true "" ""
"site14" 1.0 0 -16777216 true "" ""

INPUTBOX
18
742
184
802
maximum-feeding-patch-resource-level
1000
1
0
Number

CHOOSER
589
166
814
211
the-map
the-map
"sooi_partial" "sooi_all" "sooi_all_equal" "round" "kelonia" "ellipse"
1

TEXTBOX
29
1242
244
1260
MIGRATION
16
0.0
1

TEXTBOX
31
1276
181
1294
Expenditure
12
0.0
1

TEXTBOX
267
1275
417
1293
Imposed Thresholds
12
0.0
1

TEXTBOX
21
663
171
682
SITE DEPLETION
16
0.0
1

TEXTBOX
25
1014
230
1052
FEEDING
16
0.0
1

TEXTBOX
19
1684
169
1703
PLOTS
16
0.0
1

CHOOSER
232
1097
511
1142
foraging-migration-decision
foraging-migration-decision
"strategy-around-threshold" "strategy-below-threshold" "random"
0

BUTTON
673
591
854
624
Write
write-files
NIL
1
T
OBSERVER
NIL
W
NIL
NIL
1

INPUTBOX
909
1096
1079
1156
feeding-patch-leaving-threshold
500
1
0
Number

INPUTBOX
767
1096
901
1156
fidelity-strategy-indice
0.1
1
0
Number

CHOOSER
518
1097
764
1142
feeding-patch-fidelity-strategy
feeding-patch-fidelity-strategy
"fixed" "random"
0

INPUTBOX
530
1540
740
1600
max-nesting-duration
90
1
0
Number

CHOOSER
259
1303
452
1348
prenesting-start-method
prenesting-start-method
"threshold" "distance-dependant"
1

TEXTBOX
658
1568
689
1602
days
12
0.0
1

CHOOSER
591
264
839
309
initial-feeding-patch-allocation
initial-feeding-patch-allocation
"decreasing-exponential" "random"
0

TEXTBOX
594
80
744
98
INITIALIZATION
12
0.0
1

TEXTBOX
876
82
1026
100
OUTPUT
12
0.0
1

TEXTBOX
19
1110
226
1144
Strategy I :\nForaging site leaving decision
14
65.0
1

INPUTBOX
386
1540
521
1600
nesting-strategy-indice
0.1
1
0
Number

CHOOSER
243
1540
386
1585
nesting-strategy
nesting-strategy
"fixed" "random"
0

TEXTBOX
37
1563
223
1608
Strategy II :\nNesting Allocation Strategy
14
65.0
1

TEXTBOX
206
716
229
734
On
12
0.0
1

TEXTBOX
379
721
403
739
Off
12
0.0
1

TEXTBOX
30
1417
180
1436
NESTING
16
0.0
1

PLOT
632
3376
1188
3713
evolution-of-mean-site-stock
NIL
NIL
0.0
10.0
0.0
1000.0
true
false
"" ""
PENS
"mean-site-stock" 1.0 0 -16777216 true "" ""

CHOOSER
590
215
815
260
nesting-attribution-method
nesting-attribution-method
"fixed" "equal-number" "random"
0

SWITCH
875
105
1095
138
running-on-supercomp
running-on-supercomp
1
1
-1000

SWITCH
592
318
741
351
sea-currents
sea-currents
0
1
-1000

CHOOSER
17
863
218
908
perturbation-type
perturbation-type
"none" "distance-dependant" "latitude-dependant" "longitude-dependant"
2

INPUTBOX
17
919
178
979
perturbation-x
0
1
0
Number

INPUTBOX
184
919
345
979
perturbation-y
-26
1
0
Number

INPUTBOX
351
919
468
979
perturbation-range
1000
1
0
Number

TEXTBOX
422
954
471
972
km\n
12
0.0
1

SLIDER
237
865
450
898
perturbation-intensity
perturbation-intensity
0
1
0.1
0.01
1
NIL
HORIZONTAL

TEXTBOX
20
834
194
872
SITE PERTURBATION
16
0.0
1

SWITCH
824
400
1001
433
record-migration
record-migration
0
1
-1000

SWITCH
1004
400
1167
433
record-nesting
record-nesting
0
1
-1000

SWITCH
1101
105
1268
138
movie
movie
1
1
-1000

@#$#@#$#@
## CHANGELOG

_

## WHAT IS IT?

This a spatialised individual-based model on green sea turtles Chelonia mydas in the South-West of Indian Ocean (SWIO).
The objectives is to study the importance of spatial caracteristics of the region to the reproductive output of green sea turtles.


## HOW IT WORKS

This section could explain what rules the agents use to create the overall behavior of the model.

## HOW TO USE IT

This section could explain how to use the model, including a description of each of the items in the interface tab.

## THINGS TO NOTICE

This section could give some ideas of things for the user to notice while running the model.

## THINGS TO TRY

This section could give some ideas of things for the user to try to do (move sliders, switches, etc.) with the model.

## EXTENDING THE MODEL

This section could give some ideas of things to add or change in the procedures tab to make the model more complicated, detailed, accurate, etc.

## NETLOGO FEATURES

This section could point out any especially interesting or unusual features of NetLogo that the model makes use of, particularly in the Procedures tab.  It might also point out places where workarounds were needed because of missing features.

## RELATED MODELS

This section could give the names of models in the NetLogo Models Library or elsewhere which are of related interest.

## CREDITS AND REFERENCES

© M.DALLEAU, 2009-2014. University of La Réunion, CNRS-CEFE, IFREMER, Kélonia.

Contact:
mayeuldalleau@kelonia.org

Websites:
http://www.ifremer.fr/lareunion
http://www.kelonia.org

Contributors:
Mayeul DALLEAU, University of La Réunion, CNRS-CEFE, IFREMER, Kélonia
Daniel DAVID, University of La Réunion, LIM-IREMIA
Yassine GANGAT, University of La Réunion, LIM-IREMIA
Nicolas SEBASTIEN, University of La Réunion, LIM-IREMIA
Denis PAYET, University of La Réunion, LIM-IREMIA
Stephanie KRAMER-SCHADT, IZW Berlin
Volker GRIMM, UFZ Leipzig
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
0
Rectangle -7500403 true true 151 225 180 285
Rectangle -7500403 true true 47 225 75 285
Rectangle -7500403 true true 15 75 210 225
Circle -7500403 true true 135 75 150
Circle -16777216 true false 165 76 116

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.3.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="1910_0_2" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-feeding-nesting-usage</final>
    <timeLimit steps="40150"/>
    <metric>simulation-start-date</metric>
    <metric>simulation-end-date</metric>
    <enumeratedValueSet variable="foraging-migration">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-food-intake-foraging">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-to-plot">
      <value value="&quot;site1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="record">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration-decision">
      <value value="&quot;strategy-around-threshold&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decreasing-exponent">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy-indice">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-fidelity-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allocate-new-feeding-site-method">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prenesting-start-method">
      <value value="&quot;distance-dependant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-feeding-site-allocation">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-days-of-integration">
      <value value="36"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-depletion">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-leaving-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="depletion-coefficient">
      <value value="1.0E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fidelity-strategy-indice">
      <value value="0"/>
      <value value="0.1"/>
      <value value="0.2"/>
      <value value="0.3"/>
      <value value="0.4"/>
      <value value="0.6"/>
      <value value="0.7"/>
      <value value="0.8"/>
      <value value="0.9"/>
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimal-remigration-interval">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-nesting">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-migration">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-nesting-duration">
      <value value="90"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="keep-tracks">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nb-gturtles">
      <value value="6580"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="the-map">
      <value value="&quot;sooi2&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="display-plots">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gis">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimal-energy-for-prenesting">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-seagrass-stock-level">
      <value value="1000"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="20121018_test" repetitions="2" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <final>write-feeding-nesting-usage</final>
    <timeLimit steps="100"/>
    <metric>simulation-start-date</metric>
    <metric>simulation-end-date</metric>
    <enumeratedValueSet variable="foraging-migration">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-fidelity-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-nesting-duration">
      <value value="45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="the-map">
      <value value="&quot;sooi2&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-seagrass-stock-level">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-days-of-integration">
      <value value="36"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-to-plot">
      <value value="&quot;site1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-leaving-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration-decision">
      <value value="&quot;strategy-around-threshold&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allocate-new-feeding-site-method">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fidelity-strategy-indice">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="display-plots">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-depletion">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prenesting-start-method">
      <value value="&quot;distance-dependant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="keep-tracks">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimal-energy-for-prenesting">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-migration">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-food-intake-foraging">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="record">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="depletion-coefficient">
      <value value="1.0E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nb-gturtles">
      <value value="6580"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy-indice">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decreasing-exponent">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimal-remigration-interval">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-nesting">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-feeding-site-allocation">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gis">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="20121019_calibrate_nesting_cost" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-feeding-nesting-usage</final>
    <timeLimit steps="10000"/>
    <metric>simulation-start-date</metric>
    <metric>simulation-end-date</metric>
    <enumeratedValueSet variable="initial-feeding-site-allocation">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimal-energy-for-prenesting">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-fidelity-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gis">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="the-map">
      <value value="&quot;sooi_partial&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="record">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimal-remigration-interval">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-days-of-integration">
      <value value="36"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nb-gturtles">
      <value value="7000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-seagrass-stock-level">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-to-plot">
      <value value="&quot;site1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-migration">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-nesting-duration">
      <value value="45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration-decision">
      <value value="&quot;strategy-around-threshold&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allocate-new-feeding-site-method">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-depletion">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fidelity-strategy-indice">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prenesting-start-method">
      <value value="&quot;distance-dependant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="keep-tracks">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy-indice">
      <value value="0.1"/>
      <value value="0.5"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-attribution-method">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-food-intake-foraging">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-nesting">
      <value value="5"/>
      <value value="50"/>
      <value value="200"/>
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="depletion-coefficient">
      <value value="1.0E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decreasing-exponent">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-leaving-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="display-plots">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="running-on-metis">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="20121019_calibrate_nesting_cost_computation_time" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-feeding-nesting-usage</final>
    <timeLimit steps="1000"/>
    <metric>simulation-start-date</metric>
    <metric>simulation-end-date</metric>
    <enumeratedValueSet variable="initial-feeding-site-allocation">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimal-energy-for-prenesting">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-fidelity-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gis">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="the-map">
      <value value="&quot;sooi_partial&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="record">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimal-remigration-interval">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-days-of-integration">
      <value value="36"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nb-gturtles">
      <value value="7000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-seagrass-stock-level">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-to-plot">
      <value value="&quot;site1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-migration">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-nesting-duration">
      <value value="45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration-decision">
      <value value="&quot;strategy-around-threshold&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allocate-new-feeding-site-method">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-depletion">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fidelity-strategy-indice">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prenesting-start-method">
      <value value="&quot;distance-dependant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="keep-tracks">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy-indice">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-attribution-method">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-food-intake-foraging">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-nesting">
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="depletion-coefficient">
      <value value="1.0E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decreasing-exponent">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-leaving-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="display-plots">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="running-on-metis">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="20121019_calibrate_nesting_cost2" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-feeding-nesting-usage</final>
    <timeLimit steps="10000"/>
    <metric>simulation-start-date</metric>
    <metric>simulation-end-date</metric>
    <enumeratedValueSet variable="initial-feeding-site-allocation">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimal-energy-for-prenesting">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-fidelity-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="gis">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="the-map">
      <value value="&quot;sooi_partial&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="record">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimal-remigration-interval">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-days-of-integration">
      <value value="36"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nb-gturtles">
      <value value="7000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-seagrass-stock-level">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-to-plot">
      <value value="&quot;site1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-migration">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-nesting-duration">
      <value value="45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration-decision">
      <value value="&quot;strategy-around-threshold&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allocate-new-feeding-site-method">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-depletion">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fidelity-strategy-indice">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prenesting-start-method">
      <value value="&quot;distance-dependant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="keep-tracks">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy-indice">
      <value value="0.1"/>
      <value value="0.5"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-attribution-method">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-food-intake-foraging">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-nesting">
      <value value="10"/>
      <value value="25"/>
      <value value="75"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="depletion-coefficient">
      <value value="1.0E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decreasing-exponent">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-leaving-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="display-plots">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="running-on-metis">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="20121029_strategy1" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-feeding-nesting-usage</final>
    <timeLimit steps="36500"/>
    <metric>simulation-start-date</metric>
    <metric>simulation-end-date</metric>
    <enumeratedValueSet variable="minimal-energy-for-prenesting">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-maximum-distance">
      <value value="1500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-depletion">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="running-on-metis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fidelity-strategy-indice">
      <value value="0.1"/>
      <value value="0.5"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-x">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="keep-tracks">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-intensity">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nb-gturtles">
      <value value="7000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="display-plots">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-to-plot">
      <value value="&quot;site1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-feeding-site-allocation">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="record">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prenesting-start-method">
      <value value="&quot;distance-dependant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-type">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-y">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-fidelity-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimal-remigration-interval">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy-indice">
      <value value="0.1"/>
      <value value="0.5"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-food-intake-foraging">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-leaving-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sea-currents">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="depletion-coefficient">
      <value value="1.0E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allocate-new-feeding-site-method">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="the-map">
      <value value="&quot;sooi_all&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-days-of-integration">
      <value value="36"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-attribution-method">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration-decision">
      <value value="&quot;strategy-around-threshold&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-migration">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decreasing-exponent">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-nesting-duration">
      <value value="45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-nesting">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-seagrass-stock-level">
      <value value="1000"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="20121029_strategy_test_single" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-feeding-nesting-usage</final>
    <timeLimit steps="13000"/>
    <metric>simulation-start-date</metric>
    <metric>simulation-end-date</metric>
    <enumeratedValueSet variable="minimal-energy-for-prenesting">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-maximum-distance">
      <value value="1500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-depletion">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="running-on-metis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fidelity-strategy-indice">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-x">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="keep-tracks">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-intensity">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nb-gturtles">
      <value value="7000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="display-plots">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-to-plot">
      <value value="&quot;site1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-feeding-site-allocation">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="record">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prenesting-start-method">
      <value value="&quot;distance-dependant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-type">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-y">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-fidelity-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimal-remigration-interval">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy-indice">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-food-intake-foraging">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-leaving-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sea-currents">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="depletion-coefficient">
      <value value="1.0E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allocate-new-feeding-site-method">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="the-map">
      <value value="&quot;sooi_all&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-days-of-integration">
      <value value="36"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-attribution-method">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration-decision">
      <value value="&quot;strategy-around-threshold&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-migration">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decreasing-exponent">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-nesting-duration">
      <value value="45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-nesting">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-seagrass-stock-level">
      <value value="1000"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="20121029_strategy2" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-feeding-nesting-usage</final>
    <timeLimit steps="36500"/>
    <metric>simulation-start-date</metric>
    <metric>simulation-end-date</metric>
    <enumeratedValueSet variable="minimal-energy-for-prenesting">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-maximum-distance">
      <value value="1500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-depletion">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="running-on-metis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fidelity-strategy-indice">
      <value value="0.1"/>
      <value value="0.5"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-x">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="keep-tracks">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-intensity">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nb-gturtles">
      <value value="7000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="display-plots">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-to-plot">
      <value value="&quot;site1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-feeding-site-allocation">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="record">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prenesting-start-method">
      <value value="&quot;distance-dependant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-type">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-y">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-fidelity-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimal-remigration-interval">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy-indice">
      <value value="0.1"/>
      <value value="0.5"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-food-intake-foraging">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-leaving-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sea-currents">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="depletion-coefficient">
      <value value="1.0E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allocate-new-feeding-site-method">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="the-map">
      <value value="&quot;sooi_all&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-days-of-integration">
      <value value="36"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-attribution-method">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration-decision">
      <value value="&quot;strategy-around-threshold&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-migration">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decreasing-exponent">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-nesting-duration">
      <value value="45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-nesting">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-seagrass-stock-level">
      <value value="1000"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="20121029_strategy3" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-feeding-nesting-usage</final>
    <timeLimit steps="36500"/>
    <metric>simulation-start-date</metric>
    <metric>simulation-end-date</metric>
    <enumeratedValueSet variable="minimal-energy-for-prenesting">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-maximum-distance">
      <value value="1500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-depletion">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="running-on-metis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fidelity-strategy-indice">
      <value value="0.1"/>
      <value value="0.5"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-x">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="keep-tracks">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-intensity">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nb-gturtles">
      <value value="7000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="display-plots">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-to-plot">
      <value value="&quot;site1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-feeding-site-allocation">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="record">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prenesting-start-method">
      <value value="&quot;distance-dependant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-type">
      <value value="&quot;latitude-dependant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-y">
      <value value="-30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-fidelity-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimal-remigration-interval">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy-indice">
      <value value="0.1"/>
      <value value="0.5"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-food-intake-foraging">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-leaving-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sea-currents">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="depletion-coefficient">
      <value value="1.0E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allocate-new-feeding-site-method">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="the-map">
      <value value="&quot;sooi_all&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-days-of-integration">
      <value value="36"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-attribution-method">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration-decision">
      <value value="&quot;strategy-around-threshold&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-migration">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decreasing-exponent">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-nesting-duration">
      <value value="45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-nesting">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-seagrass-stock-level">
      <value value="1000"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="20121030_strategy1" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-feeding-nesting-usage</final>
    <timeLimit steps="36500"/>
    <metric>simulation-start-date</metric>
    <metric>simulation-end-date</metric>
    <enumeratedValueSet variable="minimal-energy-for-prenesting">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-maximum-distance">
      <value value="1500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-depletion">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="running-on-metis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fidelity-strategy-indice">
      <value value="0.1"/>
      <value value="0.5"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-x">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="keep-tracks">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-intensity">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nb-gturtles">
      <value value="7000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="display-plots">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-to-plot">
      <value value="&quot;site1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-feeding-site-allocation">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="record">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prenesting-start-method">
      <value value="&quot;distance-dependant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-type">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-y">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-fidelity-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimal-remigration-interval">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy-indice">
      <value value="0.1"/>
      <value value="0.5"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-food-intake-foraging">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-leaving-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sea-currents">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="depletion-coefficient">
      <value value="1.0E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allocate-new-feeding-site-method">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="the-map">
      <value value="&quot;sooi_all&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-days-of-integration">
      <value value="36"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-attribution-method">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration-decision">
      <value value="&quot;strategy-around-threshold&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-migration">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decreasing-exponent">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-nesting-duration">
      <value value="45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-nesting">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-seagrass-stock-level">
      <value value="1000"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="20121030_strategy2" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-feeding-nesting-usage</final>
    <timeLimit steps="36500"/>
    <metric>simulation-start-date</metric>
    <metric>simulation-end-date</metric>
    <enumeratedValueSet variable="minimal-energy-for-prenesting">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-maximum-distance">
      <value value="1500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-depletion">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="running-on-metis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fidelity-strategy-indice">
      <value value="0.1"/>
      <value value="0.5"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-x">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="keep-tracks">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-intensity">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nb-gturtles">
      <value value="7000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="display-plots">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-to-plot">
      <value value="&quot;site1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-feeding-site-allocation">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="record">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prenesting-start-method">
      <value value="&quot;distance-dependant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-type">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-y">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-fidelity-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimal-remigration-interval">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy-indice">
      <value value="0.1"/>
      <value value="0.5"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-food-intake-foraging">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-leaving-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sea-currents">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="depletion-coefficient">
      <value value="1.0E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allocate-new-feeding-site-method">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="the-map">
      <value value="&quot;sooi_all&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-days-of-integration">
      <value value="36"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-attribution-method">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration-decision">
      <value value="&quot;strategy-around-threshold&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-migration">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decreasing-exponent">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-nesting-duration">
      <value value="45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-nesting">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-seagrass-stock-level">
      <value value="1000"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="20121030_strategy3" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-feeding-nesting-usage</final>
    <timeLimit steps="36500"/>
    <metric>simulation-start-date</metric>
    <metric>simulation-end-date</metric>
    <enumeratedValueSet variable="minimal-energy-for-prenesting">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-maximum-distance">
      <value value="1500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-depletion">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="running-on-metis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fidelity-strategy-indice">
      <value value="0.1"/>
      <value value="0.5"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-x">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="keep-tracks">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-intensity">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nb-gturtles">
      <value value="7000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="display-plots">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-to-plot">
      <value value="&quot;site1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-feeding-site-allocation">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="record">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prenesting-start-method">
      <value value="&quot;distance-dependant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-type">
      <value value="&quot;latitude-dependant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-y">
      <value value="-30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-fidelity-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimal-remigration-interval">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy-indice">
      <value value="0.1"/>
      <value value="0.5"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-food-intake-foraging">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-leaving-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sea-currents">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="depletion-coefficient">
      <value value="1.0E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allocate-new-feeding-site-method">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="the-map">
      <value value="&quot;sooi_all&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-days-of-integration">
      <value value="36"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-attribution-method">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration-decision">
      <value value="&quot;strategy-around-threshold&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-migration">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decreasing-exponent">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-nesting-duration">
      <value value="45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-nesting">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-seagrass-stock-level">
      <value value="1000"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="20121031_test" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-feeding-nesting-usage</final>
    <timeLimit steps="365"/>
    <metric>simulation-start-date</metric>
    <metric>simulation-end-date</metric>
    <enumeratedValueSet variable="minimal-energy-for-prenesting">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-maximum-distance">
      <value value="1500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-depletion">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="running-on-metis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fidelity-strategy-indice">
      <value value="0.1"/>
      <value value="0.5"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-x">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="keep-tracks">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-intensity">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nb-gturtles">
      <value value="7000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="display-plots">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-to-plot">
      <value value="&quot;site1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-feeding-site-allocation">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="record">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prenesting-start-method">
      <value value="&quot;distance-dependant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-type">
      <value value="&quot;latitude-dependant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-y">
      <value value="-30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-fidelity-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimal-remigration-interval">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy-indice">
      <value value="0.1"/>
      <value value="0.5"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-food-intake-foraging">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-leaving-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sea-currents">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="depletion-coefficient">
      <value value="1.0E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allocate-new-feeding-site-method">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="the-map">
      <value value="&quot;sooi_all&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-days-of-integration">
      <value value="36"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-attribution-method">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration-decision">
      <value value="&quot;strategy-around-threshold&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-migration">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decreasing-exponent">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-nesting-duration">
      <value value="45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-nesting">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-seagrass-stock-level">
      <value value="1000"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="20121031_strategy4" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-feeding-nesting-usage</final>
    <timeLimit steps="36500"/>
    <metric>simulation-start-date</metric>
    <metric>simulation-end-date</metric>
    <enumeratedValueSet variable="minimal-energy-for-prenesting">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-maximum-distance">
      <value value="1500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-depletion">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="running-on-metis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fidelity-strategy-indice">
      <value value="0.1"/>
      <value value="0.5"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-x">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="keep-tracks">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-intensity">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nb-gturtles">
      <value value="7000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="display-plots">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-to-plot">
      <value value="&quot;site1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-feeding-site-allocation">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="record">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prenesting-start-method">
      <value value="&quot;distance-dependant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-type">
      <value value="&quot;latitude-dependant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-y">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-fidelity-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimal-remigration-interval">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy-indice">
      <value value="0.1"/>
      <value value="0.5"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-food-intake-foraging">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-leaving-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sea-currents">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="depletion-coefficient">
      <value value="1.0E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allocate-new-feeding-site-method">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="the-map">
      <value value="&quot;sooi_all&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-days-of-integration">
      <value value="36"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-attribution-method">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration-decision">
      <value value="&quot;strategy-around-threshold&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-migration">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decreasing-exponent">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-nesting-duration">
      <value value="45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-nesting">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-seagrass-stock-level">
      <value value="1000"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="20121102_strategy3" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-feeding-nesting-usage</final>
    <timeLimit steps="36500"/>
    <metric>simulation-start-date</metric>
    <metric>simulation-end-date</metric>
    <enumeratedValueSet variable="minimal-energy-for-prenesting">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-maximum-distance">
      <value value="1500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-depletion">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="running-on-metis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fidelity-strategy-indice">
      <value value="0.1"/>
      <value value="0.5"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-x">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="keep-tracks">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-intensity">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nb-gturtles">
      <value value="7000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="display-plots">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-to-plot">
      <value value="&quot;site1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-feeding-site-allocation">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="record">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prenesting-start-method">
      <value value="&quot;distance-dependant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-type">
      <value value="&quot;latitude-dependant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-y">
      <value value="-30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-fidelity-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimal-remigration-interval">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy-indice">
      <value value="0.1"/>
      <value value="0.5"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-food-intake-foraging">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-leaving-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sea-currents">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="depletion-coefficient">
      <value value="1.0E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allocate-new-feeding-site-method">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="the-map">
      <value value="&quot;sooi_all&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-days-of-integration">
      <value value="36"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-attribution-method">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration-decision">
      <value value="&quot;strategy-around-threshold&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-migration">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decreasing-exponent">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-nesting-duration">
      <value value="45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-nesting">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-seagrass-stock-level">
      <value value="1000"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="20121226_strategy1_rep2" repetitions="2" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-feeding-nesting-usage</final>
    <timeLimit steps="36500"/>
    <metric>simulation-start-date</metric>
    <metric>simulation-end-date</metric>
    <enumeratedValueSet variable="minimal-energy-for-prenesting">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-maximum-distance">
      <value value="1500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-depletion">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="running-on-metis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fidelity-strategy-indice">
      <value value="0.1"/>
      <value value="0.5"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-x">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="keep-tracks">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-intensity">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nb-gturtles">
      <value value="7000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="display-plots">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-to-plot">
      <value value="&quot;site1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-feeding-site-allocation">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="record">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prenesting-start-method">
      <value value="&quot;distance-dependant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-type">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-y">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-fidelity-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimal-remigration-interval">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy-indice">
      <value value="0.1"/>
      <value value="0.5"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-food-intake-foraging">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-leaving-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sea-currents">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="depletion-coefficient">
      <value value="1.0E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allocate-new-feeding-site-method">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="the-map">
      <value value="&quot;sooi_all&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-days-of-integration">
      <value value="36"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-attribution-method">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration-decision">
      <value value="&quot;strategy-around-threshold&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-migration">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decreasing-exponent">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-nesting-duration">
      <value value="45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-nesting">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-seagrass-stock-level">
      <value value="1000"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="20121226_strategy1_rep1" repetitions="2" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-feeding-nesting-usage</final>
    <timeLimit steps="36500"/>
    <metric>simulation-start-date</metric>
    <metric>simulation-end-date</metric>
    <enumeratedValueSet variable="minimal-energy-for-prenesting">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-maximum-distance">
      <value value="1500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-depletion">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="running-on-metis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fidelity-strategy-indice">
      <value value="0.1"/>
      <value value="0.5"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-x">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="keep-tracks">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-intensity">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nb-gturtles">
      <value value="7000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="display-plots">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-to-plot">
      <value value="&quot;site1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-feeding-site-allocation">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="record">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prenesting-start-method">
      <value value="&quot;distance-dependant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-type">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-y">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-fidelity-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimal-remigration-interval">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy-indice">
      <value value="0.1"/>
      <value value="0.5"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-food-intake-foraging">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-leaving-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sea-currents">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="depletion-coefficient">
      <value value="1.0E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allocate-new-feeding-site-method">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="the-map">
      <value value="&quot;sooi_all&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-days-of-integration">
      <value value="36"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-attribution-method">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration-decision">
      <value value="&quot;strategy-around-threshold&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-migration">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decreasing-exponent">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-nesting-duration">
      <value value="45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-nesting">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-seagrass-stock-level">
      <value value="1000"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="20121226_strategy2_rep1" repetitions="2" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-feeding-nesting-usage</final>
    <timeLimit steps="36500"/>
    <metric>simulation-start-date</metric>
    <metric>simulation-end-date</metric>
    <enumeratedValueSet variable="minimal-energy-for-prenesting">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-maximum-distance">
      <value value="1500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-depletion">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="running-on-metis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fidelity-strategy-indice">
      <value value="0.1"/>
      <value value="0.5"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-x">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="keep-tracks">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-intensity">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nb-gturtles">
      <value value="7000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="display-plots">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-to-plot">
      <value value="&quot;site1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-feeding-site-allocation">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="record">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prenesting-start-method">
      <value value="&quot;distance-dependant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-type">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-y">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-fidelity-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimal-remigration-interval">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy-indice">
      <value value="0.1"/>
      <value value="0.5"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-food-intake-foraging">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-leaving-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sea-currents">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="depletion-coefficient">
      <value value="1.0E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allocate-new-feeding-site-method">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="the-map">
      <value value="&quot;sooi_all&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-days-of-integration">
      <value value="36"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-attribution-method">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration-decision">
      <value value="&quot;strategy-around-threshold&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-migration">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decreasing-exponent">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-nesting-duration">
      <value value="45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-nesting">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-seagrass-stock-level">
      <value value="1000"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="20121226_strategy2_rep2" repetitions="2" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-feeding-nesting-usage</final>
    <timeLimit steps="36500"/>
    <metric>simulation-start-date</metric>
    <metric>simulation-end-date</metric>
    <enumeratedValueSet variable="minimal-energy-for-prenesting">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-maximum-distance">
      <value value="1500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-depletion">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="running-on-metis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fidelity-strategy-indice">
      <value value="0.1"/>
      <value value="0.5"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-x">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="keep-tracks">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-intensity">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nb-gturtles">
      <value value="7000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="display-plots">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-to-plot">
      <value value="&quot;site1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-feeding-site-allocation">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="record">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prenesting-start-method">
      <value value="&quot;distance-dependant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-type">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-y">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-fidelity-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimal-remigration-interval">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy-indice">
      <value value="0.1"/>
      <value value="0.5"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-food-intake-foraging">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-leaving-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sea-currents">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="depletion-coefficient">
      <value value="1.0E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allocate-new-feeding-site-method">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="the-map">
      <value value="&quot;sooi_all&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-days-of-integration">
      <value value="36"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-attribution-method">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration-decision">
      <value value="&quot;strategy-around-threshold&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-migration">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decreasing-exponent">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-nesting-duration">
      <value value="45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-nesting">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-seagrass-stock-level">
      <value value="1000"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="20121226_strategy3_rep1" repetitions="2" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-feeding-nesting-usage</final>
    <timeLimit steps="36500"/>
    <metric>simulation-start-date</metric>
    <metric>simulation-end-date</metric>
    <enumeratedValueSet variable="minimal-energy-for-prenesting">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-maximum-distance">
      <value value="1500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-depletion">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="running-on-metis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fidelity-strategy-indice">
      <value value="0.1"/>
      <value value="0.5"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-x">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="keep-tracks">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-intensity">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nb-gturtles">
      <value value="7000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="display-plots">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-to-plot">
      <value value="&quot;site1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-feeding-site-allocation">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="record">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prenesting-start-method">
      <value value="&quot;distance-dependant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-type">
      <value value="&quot;latitude-dependant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-y">
      <value value="-30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-fidelity-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimal-remigration-interval">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy-indice">
      <value value="0.1"/>
      <value value="0.5"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-food-intake-foraging">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-leaving-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sea-currents">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="depletion-coefficient">
      <value value="1.0E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allocate-new-feeding-site-method">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="the-map">
      <value value="&quot;sooi_all&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-days-of-integration">
      <value value="36"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-attribution-method">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration-decision">
      <value value="&quot;strategy-around-threshold&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-migration">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decreasing-exponent">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-nesting-duration">
      <value value="45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-nesting">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-seagrass-stock-level">
      <value value="1000"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="20121226_strategy3_rep2" repetitions="2" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-feeding-nesting-usage</final>
    <timeLimit steps="36500"/>
    <metric>simulation-start-date</metric>
    <metric>simulation-end-date</metric>
    <enumeratedValueSet variable="minimal-energy-for-prenesting">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-maximum-distance">
      <value value="1500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-depletion">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="running-on-metis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fidelity-strategy-indice">
      <value value="0.1"/>
      <value value="0.5"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-x">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="keep-tracks">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-intensity">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nb-gturtles">
      <value value="7000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="display-plots">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-to-plot">
      <value value="&quot;site1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-feeding-site-allocation">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="record">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prenesting-start-method">
      <value value="&quot;distance-dependant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-type">
      <value value="&quot;latitude-dependant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-y">
      <value value="-30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-fidelity-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimal-remigration-interval">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy-indice">
      <value value="0.1"/>
      <value value="0.5"/>
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-food-intake-foraging">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-leaving-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sea-currents">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="depletion-coefficient">
      <value value="1.0E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allocate-new-feeding-site-method">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="the-map">
      <value value="&quot;sooi_all&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-days-of-integration">
      <value value="36"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-attribution-method">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration-decision">
      <value value="&quot;strategy-around-threshold&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-migration">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decreasing-exponent">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-nesting-duration">
      <value value="45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-nesting">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-seagrass-stock-level">
      <value value="1000"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="20121226_strategy1_test" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-feeding-nesting-usage</final>
    <timeLimit steps="1000"/>
    <metric>simulation-start-date</metric>
    <metric>simulation-end-date</metric>
    <enumeratedValueSet variable="minimal-energy-for-prenesting">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-maximum-distance">
      <value value="1500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-depletion">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="running-on-metis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fidelity-strategy-indice">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-x">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="keep-tracks">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-intensity">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nb-gturtles">
      <value value="7000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="display-plots">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-to-plot">
      <value value="&quot;site1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-feeding-site-allocation">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="record">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prenesting-start-method">
      <value value="&quot;distance-dependant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-type">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-y">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-fidelity-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimal-remigration-interval">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy-indice">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-food-intake-foraging">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-leaving-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sea-currents">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="depletion-coefficient">
      <value value="1.0E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allocate-new-feeding-site-method">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="the-map">
      <value value="&quot;sooi_all&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-days-of-integration">
      <value value="36"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-attribution-method">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration-decision">
      <value value="&quot;strategy-around-threshold&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-migration">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decreasing-exponent">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-nesting-duration">
      <value value="45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-nesting">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-seagrass-stock-level">
      <value value="1000"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="20121226_strategy2_rep1_single" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-feeding-nesting-usage</final>
    <timeLimit steps="36500"/>
    <metric>simulation-start-date</metric>
    <metric>simulation-end-date</metric>
    <enumeratedValueSet variable="minimal-energy-for-prenesting">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-maximum-distance">
      <value value="1500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-depletion">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="running-on-metis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fidelity-strategy-indice">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-x">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="keep-tracks">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-intensity">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nb-gturtles">
      <value value="7000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="display-plots">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-to-plot">
      <value value="&quot;site1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-feeding-site-allocation">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="record">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prenesting-start-method">
      <value value="&quot;distance-dependant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-type">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-y">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-fidelity-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimal-remigration-interval">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy-indice">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-food-intake-foraging">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-leaving-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sea-currents">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="depletion-coefficient">
      <value value="1.0E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allocate-new-feeding-site-method">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="the-map">
      <value value="&quot;sooi_all&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-days-of-integration">
      <value value="36"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-attribution-method">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration-decision">
      <value value="&quot;strategy-around-threshold&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-migration">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decreasing-exponent">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-nesting-duration">
      <value value="45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-nesting">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-seagrass-stock-level">
      <value value="1000"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="20130328_strategy1_13rep" repetitions="13" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-feeding-nesting-usage</final>
    <timeLimit steps="36500"/>
    <metric>simulation-start-date</metric>
    <metric>simulation-end-date</metric>
    <enumeratedValueSet variable="minimal-energy-for-prenesting">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-maximum-distance">
      <value value="1500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-depletion">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="running-on-metis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fidelity-strategy-indice">
      <value value="0.2"/>
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-x">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="keep-tracks">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-intensity">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nb-gturtles">
      <value value="7000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="display-plots">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-to-plot">
      <value value="&quot;site1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-feeding-site-allocation">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="record">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prenesting-start-method">
      <value value="&quot;distance-dependant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-type">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-y">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-fidelity-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimal-remigration-interval">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy-indice">
      <value value="0.2"/>
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-food-intake-foraging">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-leaving-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sea-currents">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="depletion-coefficient">
      <value value="1.0E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allocate-new-feeding-site-method">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="the-map">
      <value value="&quot;sooi_all&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-days-of-integration">
      <value value="36"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-attribution-method">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration-decision">
      <value value="&quot;strategy-around-threshold&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-migration">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decreasing-exponent">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-nesting-duration">
      <value value="45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-nesting">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-seagrass-stock-level">
      <value value="1000"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="20130328_strategy1_2rep" repetitions="2" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-feeding-nesting-usage</final>
    <timeLimit steps="36500"/>
    <metric>simulation-start-date</metric>
    <metric>simulation-end-date</metric>
    <enumeratedValueSet variable="minimal-energy-for-prenesting">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-maximum-distance">
      <value value="1500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-depletion">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="running-on-metis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fidelity-strategy-indice">
      <value value="0.2"/>
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-x">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="keep-tracks">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-intensity">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nb-gturtles">
      <value value="7000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="display-plots">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-to-plot">
      <value value="&quot;site1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-feeding-site-allocation">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="record">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prenesting-start-method">
      <value value="&quot;distance-dependant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-type">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-y">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-fidelity-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimal-remigration-interval">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy-indice">
      <value value="0.2"/>
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-food-intake-foraging">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-leaving-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sea-currents">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="depletion-coefficient">
      <value value="1.0E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allocate-new-feeding-site-method">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="the-map">
      <value value="&quot;sooi_all&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-days-of-integration">
      <value value="36"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-attribution-method">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration-decision">
      <value value="&quot;strategy-around-threshold&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-migration">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decreasing-exponent">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-nesting-duration">
      <value value="45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-nesting">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-seagrass-stock-level">
      <value value="1000"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="20130328_strategy2_13rep" repetitions="13" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-feeding-nesting-usage</final>
    <timeLimit steps="36500"/>
    <metric>simulation-start-date</metric>
    <metric>simulation-end-date</metric>
    <enumeratedValueSet variable="minimal-energy-for-prenesting">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-maximum-distance">
      <value value="1500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-depletion">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="running-on-metis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fidelity-strategy-indice">
      <value value="0.2"/>
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-x">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="keep-tracks">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-intensity">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nb-gturtles">
      <value value="7000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="display-plots">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-to-plot">
      <value value="&quot;site1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-feeding-site-allocation">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="record">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prenesting-start-method">
      <value value="&quot;distance-dependant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-type">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-y">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-fidelity-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimal-remigration-interval">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy-indice">
      <value value="0.2"/>
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-food-intake-foraging">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-leaving-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sea-currents">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="depletion-coefficient">
      <value value="1.0E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allocate-new-feeding-site-method">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="the-map">
      <value value="&quot;sooi_all&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-days-of-integration">
      <value value="36"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-attribution-method">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration-decision">
      <value value="&quot;strategy-around-threshold&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-migration">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decreasing-exponent">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-nesting-duration">
      <value value="45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-nesting">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-seagrass-stock-level">
      <value value="1000"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="20130328_strategy2_2rep" repetitions="2" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-feeding-nesting-usage</final>
    <timeLimit steps="36500"/>
    <metric>simulation-start-date</metric>
    <metric>simulation-end-date</metric>
    <enumeratedValueSet variable="minimal-energy-for-prenesting">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-maximum-distance">
      <value value="1500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-depletion">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="running-on-metis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fidelity-strategy-indice">
      <value value="0.2"/>
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-x">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="keep-tracks">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-intensity">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nb-gturtles">
      <value value="7000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="display-plots">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-to-plot">
      <value value="&quot;site1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-feeding-site-allocation">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="record">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prenesting-start-method">
      <value value="&quot;distance-dependant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-type">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-y">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-fidelity-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimal-remigration-interval">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy-indice">
      <value value="0.2"/>
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-food-intake-foraging">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-leaving-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sea-currents">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="depletion-coefficient">
      <value value="1.0E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allocate-new-feeding-site-method">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="the-map">
      <value value="&quot;sooi_all&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-days-of-integration">
      <value value="36"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-attribution-method">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration-decision">
      <value value="&quot;strategy-around-threshold&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-migration">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decreasing-exponent">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-nesting-duration">
      <value value="45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-nesting">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-seagrass-stock-level">
      <value value="1000"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="20130328_strategy3_13rep" repetitions="13" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-feeding-nesting-usage</final>
    <timeLimit steps="36500"/>
    <metric>simulation-start-date</metric>
    <metric>simulation-end-date</metric>
    <enumeratedValueSet variable="minimal-energy-for-prenesting">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-maximum-distance">
      <value value="1500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-depletion">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="running-on-metis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fidelity-strategy-indice">
      <value value="0.2"/>
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-x">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="keep-tracks">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-intensity">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nb-gturtles">
      <value value="7000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="display-plots">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-to-plot">
      <value value="&quot;site1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-feeding-site-allocation">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="record">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prenesting-start-method">
      <value value="&quot;distance-dependant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-type">
      <value value="&quot;latitude-dependant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-y">
      <value value="-30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-fidelity-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimal-remigration-interval">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy-indice">
      <value value="0.2"/>
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-food-intake-foraging">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-leaving-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sea-currents">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="depletion-coefficient">
      <value value="1.0E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allocate-new-feeding-site-method">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="the-map">
      <value value="&quot;sooi_all&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-days-of-integration">
      <value value="36"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-attribution-method">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration-decision">
      <value value="&quot;strategy-around-threshold&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-migration">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decreasing-exponent">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-nesting-duration">
      <value value="45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-nesting">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-seagrass-stock-level">
      <value value="1000"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="20130328_strategy3_2rep" repetitions="2" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-feeding-nesting-usage</final>
    <timeLimit steps="36500"/>
    <metric>simulation-start-date</metric>
    <metric>simulation-end-date</metric>
    <enumeratedValueSet variable="minimal-energy-for-prenesting">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-maximum-distance">
      <value value="1500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-depletion">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="running-on-metis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fidelity-strategy-indice">
      <value value="0.2"/>
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-x">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="keep-tracks">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-intensity">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nb-gturtles">
      <value value="7000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="display-plots">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-to-plot">
      <value value="&quot;site1&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-feeding-site-allocation">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="record">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prenesting-start-method">
      <value value="&quot;distance-dependant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-type">
      <value value="&quot;latitude-dependant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-y">
      <value value="-30"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-fidelity-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimal-remigration-interval">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy-indice">
      <value value="0.2"/>
      <value value="0.7"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-food-intake-foraging">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-leaving-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sea-currents">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="depletion-coefficient">
      <value value="1.0E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allocate-new-feeding-site-method">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="the-map">
      <value value="&quot;sooi_all&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-days-of-integration">
      <value value="36"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-attribution-method">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration-decision">
      <value value="&quot;strategy-around-threshold&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-migration">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decreasing-exponent">
      <value value="15"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-nesting-duration">
      <value value="45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-nesting">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-seagrass-stock-level">
      <value value="1000"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="20130408_migration" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <final>write-files</final>
    <timeLimit steps="36500"/>
    <metric>simulation-start-date</metric>
    <metric>simulation-end-date</metric>
    <enumeratedValueSet variable="movie">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="display-plots">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="depletion-coefficient">
      <value value="1.0E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-leaving-threshold">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-intensity">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimal-energy-for-prenesting">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-depletion">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-migration">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fidelity-strategy-indice">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-nesting-duration">
      <value value="45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="record-nesting">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sea-currents">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="record">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="keep-tracks">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prenesting-start-method">
      <value value="&quot;distance-dependant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allocate-new-feeding-site-method">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="record-migration">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-feeding-site-allocation">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-food-intake-foraging">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="running-on-metis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-y">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-type">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decreasing-exponent">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-fidelity-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-nesting">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-seagrass-stock-level">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-attribution-method">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimal-remigration-interval">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-days-of-integration">
      <value value="51"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration-decision">
      <value value="&quot;strategy-around-threshold&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy-indice">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="the-map">
      <value value="&quot;sooi_all&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-to-plot">
      <value value="&quot;site3&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nb-gturtles">
      <value value="7000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-maximum-distance">
      <value value="1500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-x">
      <value value="0"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="20130507_withcurr" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-files</final>
    <timeLimit steps="36500"/>
    <metric>simulation-start-date</metric>
    <metric>simulation-end-date</metric>
    <enumeratedValueSet variable="display-plots">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fidelity-strategy-indice">
      <value value="0.2"/>
      <value value="0.4"/>
      <value value="0.6"/>
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prenesting-start-method">
      <value value="&quot;distance-dependant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-to-plot">
      <value value="&quot;site3&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-intensity">
      <value value="1.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decreasing-exponent">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-days-of-integration">
      <value value="51"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-seagrass-stock-level">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="the-map">
      <value value="&quot;sooi_all&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-maximum-distance">
      <value value="2000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-attribution-method">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-y">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="record">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-leaving-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sea-currents">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-nesting">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="record-nesting">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-type">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-food-intake-foraging">
      <value value="1500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allocate-new-feeding-site-method">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-feeding-site-allocation">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="depletion-coefficient">
      <value value="1.0E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="running-on-metis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nb-gturtles">
      <value value="7000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimal-energy-for-prenesting">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="movie">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-depletion">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-migration">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration-decision">
      <value value="&quot;strategy-around-threshold&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy-indice">
      <value value="0.2"/>
      <value value="0.4"/>
      <value value="0.6"/>
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="record-migration">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-x">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimal-remigration-interval">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-fidelity-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-nesting-duration">
      <value value="45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="keep-tracks">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="20130410_withmig_single" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-files</final>
    <timeLimit steps="36500"/>
    <metric>simulation-start-date</metric>
    <metric>simulation-end-date</metric>
    <enumeratedValueSet variable="display-plots">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fidelity-strategy-indice">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prenesting-start-method">
      <value value="&quot;distance-dependant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-to-plot">
      <value value="&quot;site3&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-intensity">
      <value value="1.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decreasing-exponent">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-days-of-integration">
      <value value="51"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-seagrass-stock-level">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="the-map">
      <value value="&quot;sooi_all&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-maximum-distance">
      <value value="2000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-attribution-method">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-y">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="record">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-leaving-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sea-currents">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-nesting">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="record-nesting">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-type">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-food-intake-foraging">
      <value value="1500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allocate-new-feeding-site-method">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-feeding-site-allocation">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="depletion-coefficient">
      <value value="1.0E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="running-on-metis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nb-gturtles">
      <value value="7000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimal-energy-for-prenesting">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="movie">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-depletion">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-migration">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration-decision">
      <value value="&quot;strategy-around-threshold&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy-indice">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="record-migration">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-x">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimal-remigration-interval">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-fidelity-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-nesting-duration">
      <value value="45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="keep-tracks">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="20130410_withmig_single_withoutcurr" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-files</final>
    <timeLimit steps="36500"/>
    <metric>simulation-start-date</metric>
    <metric>simulation-end-date</metric>
    <enumeratedValueSet variable="display-plots">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fidelity-strategy-indice">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prenesting-start-method">
      <value value="&quot;distance-dependant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-to-plot">
      <value value="&quot;site3&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-intensity">
      <value value="1.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decreasing-exponent">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-days-of-integration">
      <value value="51"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-seagrass-stock-level">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="the-map">
      <value value="&quot;sooi_all&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-maximum-distance">
      <value value="2000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-attribution-method">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-y">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="record">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-leaving-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sea-currents">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-nesting">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="record-nesting">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-type">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-food-intake-foraging">
      <value value="1500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allocate-new-feeding-site-method">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-feeding-site-allocation">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="depletion-coefficient">
      <value value="1.0E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="running-on-metis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nb-gturtles">
      <value value="7000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimal-energy-for-prenesting">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="movie">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-depletion">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-migration">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration-decision">
      <value value="&quot;strategy-around-threshold&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy-indice">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="record-migration">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-x">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimal-remigration-interval">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-fidelity-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-nesting-duration">
      <value value="45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="keep-tracks">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="20130507_withmig" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-files</final>
    <timeLimit steps="36500"/>
    <metric>simulation-start-date</metric>
    <metric>simulation-end-date</metric>
    <enumeratedValueSet variable="display-plots">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fidelity-strategy-indice">
      <value value="0.2"/>
      <value value="0.4"/>
      <value value="0.6"/>
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prenesting-start-method">
      <value value="&quot;distance-dependant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-to-plot">
      <value value="&quot;site3&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-intensity">
      <value value="1.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decreasing-exponent">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-days-of-integration">
      <value value="51"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-seagrass-stock-level">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="the-map">
      <value value="&quot;sooi_all&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-maximum-distance">
      <value value="2000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-attribution-method">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-y">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="record">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-leaving-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sea-currents">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-nesting">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="record-nesting">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-type">
      <value value="&quot;none&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-food-intake-foraging">
      <value value="1500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allocate-new-feeding-site-method">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-feeding-site-allocation">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="depletion-coefficient">
      <value value="1.0E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="running-on-metis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nb-gturtles">
      <value value="7000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimal-energy-for-prenesting">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="movie">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-depletion">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-migration">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration-decision">
      <value value="&quot;strategy-around-threshold&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy-indice">
      <value value="0.2"/>
      <value value="0.4"/>
      <value value="0.6"/>
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="record-migration">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-x">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimal-remigration-interval">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-fidelity-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-nesting-duration">
      <value value="45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="keep-tracks">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="20130507_perturb" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-files</final>
    <timeLimit steps="36500"/>
    <metric>simulation-start-date</metric>
    <metric>simulation-end-date</metric>
    <enumeratedValueSet variable="display-plots">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fidelity-strategy-indice">
      <value value="0.2"/>
      <value value="0.4"/>
      <value value="0.6"/>
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prenesting-start-method">
      <value value="&quot;distance-dependant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-to-plot">
      <value value="&quot;site3&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-intensity">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decreasing-exponent">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-days-of-integration">
      <value value="51"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-seagrass-stock-level">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="the-map">
      <value value="&quot;sooi_all&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-maximum-distance">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-attribution-method">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-y">
      <value value="-26"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="record">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-leaving-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sea-currents">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-nesting">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="record-nesting">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-type">
      <value value="&quot;latitude-dependant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-food-intake-foraging">
      <value value="1500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allocate-new-feeding-site-method">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-feeding-site-allocation">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="depletion-coefficient">
      <value value="1.0E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="running-on-metis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nb-gturtles">
      <value value="7000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimal-energy-for-prenesting">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="movie">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-depletion">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-migration">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration-decision">
      <value value="&quot;strategy-around-threshold&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy-indice">
      <value value="0.2"/>
      <value value="0.4"/>
      <value value="0.6"/>
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="record-migration">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-x">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimal-remigration-interval">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-fidelity-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-nesting-duration">
      <value value="45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="keep-tracks">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="20130410_perturb_single" repetitions="1" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <final>write-files</final>
    <timeLimit steps="36500"/>
    <metric>simulation-start-date</metric>
    <metric>simulation-end-date</metric>
    <enumeratedValueSet variable="display-plots">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fidelity-strategy-indice">
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prenesting-start-method">
      <value value="&quot;distance-dependant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-to-plot">
      <value value="&quot;site3&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-intensity">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="decreasing-exponent">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="number-of-days-of-integration">
      <value value="51"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="maximum-seagrass-stock-level">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="the-map">
      <value value="&quot;sooi_all&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-maximum-distance">
      <value value="1000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-attribution-method">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-y">
      <value value="-26"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="record">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-leaving-threshold">
      <value value="500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="sea-currents">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-nesting">
      <value value="5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="record-nesting">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-type">
      <value value="&quot;latitude-dependant&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-food-intake-foraging">
      <value value="1500"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="allocate-new-feeding-site-method">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="initial-feeding-site-allocation">
      <value value="&quot;decreasing-exponential&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="depletion-coefficient">
      <value value="1.0E-4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="running-on-metis">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nb-gturtles">
      <value value="7000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimal-energy-for-prenesting">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="movie">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="site-depletion">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="daily-energy-expenditure-migration">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="foraging-migration-decision">
      <value value="&quot;strategy-around-threshold&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nesting-strategy-indice">
      <value value="0.8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="record-migration">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="perturbation-x">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="minimal-remigration-interval">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="feeding-site-fidelity-strategy">
      <value value="&quot;fixed&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-nesting-duration">
      <value value="45"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="keep-tracks">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
